@@ -1,5 +1,6 @@
 import base64
 import datetime
+import ipaddress
 import re
 from typing import Any, Dict, Iterable, List, Optional, Set, Tuple
 
@@ -7,10 +8,11 @@ import cryptography.hazmat.primitives.asymmetric.rsa
 import cryptography.x509
 from cryptography.hazmat.backends import default_backend
 from cryptography.hazmat.primitives import hashes, serialization
-from cryptography.x509 import OID_COMMON_NAME, DNSName, NameOID
+from cryptography.x509 import OID_COMMON_NAME, DNSName, IPAddress, NameOID
 
 from moto import settings
-from moto.core import BackendDict, BaseBackend, BaseModel
+from moto.core.base_backend import BackendDict, BaseBackend
+from moto.core.common_models import BaseModel
 from moto.core.utils import utcnow
 
 from .exceptions import (
@@ -48,6 +50,10 @@ RnGfN8j8KLDVmWyTYMk8V+6j0LI4+4zFh2upqGMQHL3VFVFWBek6vCDWhB/b
 # Added aws root CA as AWS returns chain you gave it + root CA (provided or not)
 # so for now a cheap response is just give any old root CA
 
+IPV4_REGEX = re.compile(
+    r"(\b25[0-5]|\b2[0-4][0-9]|\b[01]?[0-9][0-9]?)(\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)){3}"
+)
+
 
 def datetime_to_epoch(date: datetime.datetime) -> float:
     return date.timestamp()
@@ -122,6 +128,8 @@ class CertBundle(BaseModel):
         arn: Optional[str] = None,
         cert_type: str = "IMPORTED",
         cert_status: str = "ISSUED",
+        cert_authority_arn: Optional[str] = None,
+        cert_options: Optional[Dict[str, Any]] = None,
     ):
         self.created_at = utcnow()
         self.cert = certificate
@@ -131,7 +139,12 @@ class CertBundle(BaseModel):
         self.tags = TagHolder()
         self.type = cert_type  # Should really be an enum
         self.status = cert_status  # Should really be an enum
+        self.cert_authority_arn = cert_authority_arn
         self.in_use_by: List[str] = []
+        self.cert_options = cert_options or {
+            "CertificateTransparencyLoggingPreference": "ENABLED",
+            "Export": "DISABLED",
+        }
 
         # Takes care of PEM checking
         self._key = self.validate_pk()
@@ -157,11 +170,19 @@ class CertBundle(BaseModel):
         account_id: str,
         region: str,
         sans: Optional[List[str]] = None,
+        cert_authority_arn: Optional[str] = None,
     ) -> "CertBundle":
         unique_sans: Set[str] = set(sans) if sans else set()
 
         unique_sans.add(domain_name)
-        unique_dns_names = [DNSName(item) for item in unique_sans]
+        # SSL treats IP addresses differently from regular host names
+        # https://cabforum.org/working-groups/server/guidance-ip-addresses-certificates/
+        unique_dns_names = [
+            IPAddress(ipaddress.IPv4Address(name))
+            if IPV4_REGEX.match(name)
+            else DNSName(name)
+            for name in unique_sans
+        ]
 
         key = cryptography.hazmat.primitives.asymmetric.rsa.generate_private_key(
             public_exponent=65537, key_size=2048, backend=default_backend()
@@ -212,8 +233,11 @@ class CertBundle(BaseModel):
         return cls(
             certificate=cert_armored,
             private_key=private_key,
-            cert_type="AMAZON_ISSUED",
-            cert_status="PENDING_VALIDATION",
+            cert_type="PRIVATE" if cert_authority_arn is not None else "AMAZON_ISSUED",
+            cert_status="ISSUED"
+            if cert_authority_arn is not None
+            else "PENDING_VALIDATION",
+            cert_authority_arn=cert_authority_arn,
             account_id=account_id,
             region=region,
         )
@@ -237,12 +261,12 @@ class CertBundle(BaseModel):
             )
 
             now = utcnow()
-            if _cert.not_valid_after < now:
+            if self._not_valid_after(_cert) < now:
                 raise AWSValidationException(
                     "The certificate has expired, is not valid."
                 )
 
-            if _cert.not_valid_before > now:
+            if self._not_valid_before(_cert) > now:
                 raise AWSValidationException(
                     "The certificate is not in effect yet, is not valid."
                 )
@@ -255,6 +279,22 @@ class CertBundle(BaseModel):
             )
         return _cert
 
+    def _not_valid_after(
+        self, _cert: cryptography.x509.base.Certificate
+    ) -> datetime.datetime:
+        try:
+            return _cert.not_valid_after_utc.replace(tzinfo=None)
+        except AttributeError:
+            return _cert.not_valid_after
+
+    def _not_valid_before(
+        self, _cert: cryptography.x509.base.Certificate
+    ) -> datetime.datetime:
+        try:
+            return _cert.not_valid_before_utc.replace(tzinfo=None)
+        except AttributeError:
+            return _cert.not_valid_before
+
     def validate_chain(self) -> None:
         try:
             for cert_armored in self.chain.split(b"-\n-"):
@@ -266,12 +306,12 @@ class CertBundle(BaseModel):
                 )
 
                 now = utcnow()
-                if self._cert.not_valid_after < now:
+                if self._not_valid_after(self._cert) < now:
                     raise AWSValidationException(
                         "The certificate chain has expired, is not valid."
                     )
 
-                if self._cert.not_valid_before > now:
+                if self._not_valid_before(self._cert) > now:
                     raise AWSValidationException(
                         "The certificate chain is not in effect yet, is not valid."
                     )
@@ -284,6 +324,12 @@ class CertBundle(BaseModel):
             )
 
     def check(self) -> None:
+        # Check for certificate expiration
+        now = utcnow()
+        if self._not_valid_after(self._cert) <= now:
+            self.status = "EXPIRED"
+            return
+
         # Basically, if the certificate is pending, and then checked again after a
         # while, it will appear as if its been validated. The default wait time is 60
         # seconds but you can set an environment to change it.
@@ -313,7 +359,7 @@ class CertBundle(BaseModel):
             san_obj = None
         sans = []
         if san_obj is not None:
-            sans = [item.value for item in san_obj.value]
+            sans = [str(item.value) for item in san_obj.value]
 
         result: Dict[str, Any] = {
             "Certificate": {
@@ -324,8 +370,8 @@ class CertBundle(BaseModel):
                     0
                 ].value,
                 "KeyAlgorithm": key_algo,
-                "NotAfter": datetime_to_epoch(self._cert.not_valid_after),
-                "NotBefore": datetime_to_epoch(self._cert.not_valid_before),
+                "NotAfter": datetime_to_epoch(self._not_valid_after(self._cert)),
+                "NotBefore": datetime_to_epoch(self._not_valid_before(self._cert)),
                 "Serial": str(self._cert.serial_number),
                 "SignatureAlgorithm": self._cert.signature_algorithm_oid._name.upper().replace(
                     "ENCRYPTION", ""
@@ -336,16 +382,23 @@ class CertBundle(BaseModel):
                 "Type": self.type,  # One of IMPORTED, AMAZON_ISSUED,
                 "ExtendedKeyUsages": [],
                 "RenewalEligibility": "INELIGIBLE",
-                "Options": {"CertificateTransparencyLoggingPreference": "ENABLED"},
+                "Options": self.cert_options,
             }
         }
 
+        if self.cert_authority_arn is not None:
+            result["Certificate"]["CertificateAuthorityArn"] = self.cert_authority_arn
+
         domain_names = set(sans + [self.common_name])
         validation_options = []
 
+        domain_name_status = "SUCCESS" if self.status == "ISSUED" else self.status
         for san in domain_names:
+            # https://docs.aws.amazon.com/acm/latest/userguide/dns-validation.html
+            # Record name usually follows the SAN - except when the SAN starts with an asterisk
+            rr_name = f"_d930b28be6c5927595552b219965053e.{san[2:] if san.startswith('*.') else san}."
             resource_record = {
-                "Name": f"_d930b28be6c5927595552b219965053e.{san}.",
+                "Name": rr_name,
                 "Type": "CNAME",
                 "Value": "_c9edd76ee4a0e2a74388032f3861cc50.ykybfrwcxw.acm-validations.aws.",
             }
@@ -353,13 +406,14 @@ class CertBundle(BaseModel):
                 {
                     "DomainName": san,
                     "ValidationDomain": san,
-                    "ValidationStatus": self.status,
+                    "ValidationStatus": domain_name_status,
                     "ValidationMethod": "DNS",
                     "ResourceRecord": resource_record,
                 }
             )
 
-        result["Certificate"]["DomainValidationOptions"] = validation_options
+        if self.type == "AMAZON_ISSUED":
+            result["Certificate"]["DomainValidationOptions"] = validation_options
 
         if self.type == "IMPORTED":
             result["Certificate"]["ImportedAt"] = datetime_to_epoch(self.created_at)
@@ -386,20 +440,22 @@ class CertBundle(BaseModel):
         return "<Certificate>"
 
 
+class AccountConfiguration:
+    def __init__(self, days_before_expiry: int = 45):
+        self.days_before_expiry = days_before_expiry
+
+    def to_dict(self):  # type: ignore
+        return {"ExpiryEvents": {"DaysBeforeExpiry": self.days_before_expiry}}
+
+
 class AWSCertificateManagerBackend(BaseBackend):
+    MIN_PASSPHRASE_LEN = 4
+
     def __init__(self, region_name: str, account_id: str):
         super().__init__(region_name, account_id)
         self._certificates: Dict[str, CertBundle] = {}
         self._idempotency_tokens: Dict[str, Any] = {}
-
-    @staticmethod
-    def default_vpc_endpoint_service(
-        service_region: str, zones: List[str]
-    ) -> List[Dict[str, str]]:
-        """Default VPC endpoint service."""
-        return BaseBackend.default_vpc_endpoint_service_factory(
-            service_region, zones, "acm-pca"
-        )
+        self._account_config = AccountConfiguration()
 
     def set_certificate_in_use_by(self, arn: str, load_balancer_name: str) -> None:
         if arn not in self._certificates:
@@ -437,7 +493,7 @@ class AWSCertificateManagerBackend(BaseBackend):
             "expires": utcnow() + datetime.timedelta(hours=1),
         }
 
-    def import_cert(
+    def import_certificate(
         self,
         certificate: bytes,
         private_key: bytes,
@@ -475,17 +531,18 @@ class AWSCertificateManagerBackend(BaseBackend):
 
         return bundle.arn
 
-    def get_certificates_list(self, statuses: List[str]) -> Iterable[CertBundle]:
-        """
-        Get list of certificates
-
-        :return: List of certificates
-        :rtype: list of CertBundle
-        """
+    def list_certificates(
+        self, statuses: List[str], includes: Dict[str, Any]
+    ) -> Iterable[CertBundle]:
         for arn in self._certificates.keys():
             cert = self.get_certificate(arn)
             if not statuses or cert.status in statuses:
-                yield cert
+                if not includes or (
+                    "Export" in cert.cert_options
+                    and includes.get("exportOption", None)
+                    in cert.cert_options["Export"]
+                ):
+                    yield cert
 
     def get_certificate(self, arn: str) -> CertBundle:
         if arn not in self._certificates:
@@ -495,6 +552,9 @@ class AWSCertificateManagerBackend(BaseBackend):
         cert_bundle.check()
         return cert_bundle
 
+    def describe_certificate(self, arn: str) -> CertBundle:
+        return self.get_certificate(arn)
+
     def delete_certificate(self, arn: str) -> None:
         if arn not in self._certificates:
             raise CertificateNotFound(arn=arn, account_id=self.account_id)
@@ -507,6 +567,8 @@ class AWSCertificateManagerBackend(BaseBackend):
         idempotency_token: str,
         subject_alt_names: List[str],
         tags: List[Dict[str, str]],
+        cert_authority_arn: Optional[str] = None,
+        cert_options: Optional[Dict[str, Any]] = None,
     ) -> str:
         """
         The parameter DomainValidationOptions has not yet been implemented
@@ -521,11 +583,15 @@ class AWSCertificateManagerBackend(BaseBackend):
             account_id=self.account_id,
             region=self.region_name,
             sans=subject_alt_names,
+            cert_authority_arn=cert_authority_arn,
         )
         if idempotency_token is not None:
             self._set_idempotency_token_arn(idempotency_token, cert.arn)
         self._certificates[cert.arn] = cert
 
+        if cert_options:
+            self._certificates[cert.arn].cert_options = cert_options
+
         if tags:
             cert.tags.add(tags)
 
@@ -546,14 +612,42 @@ class AWSCertificateManagerBackend(BaseBackend):
     def export_certificate(
         self, certificate_arn: str, passphrase: str
     ) -> Tuple[str, str, str]:
+        if len(passphrase) < self.MIN_PASSPHRASE_LEN:
+            raise AWSValidationException(
+                "Value at 'passphrase' failed to satisfy constraint: Member must have length greater than or equal to %s"
+                % (self.MIN_PASSPHRASE_LEN)
+            )
         passphrase_bytes = base64.standard_b64decode(passphrase)
         cert_bundle = self.get_certificate(certificate_arn)
-
+        if (cert_bundle.type != "PRIVATE") and (
+            cert_bundle.cert_options["Export"] != "ENABLED"
+        ):
+            raise AWSValidationException(
+                "Certificate ARN: %s is not a private certificate" % (certificate_arn)
+            )
         certificate = cert_bundle.cert.decode()
         certificate_chain = cert_bundle.chain.decode()
         private_key = cert_bundle.serialize_pk(passphrase_bytes)
 
         return certificate, certificate_chain, private_key
 
+    def get_account_configuration(self) -> Dict[str, Any]:
+        return self._account_config.to_dict()  # type: ignore
+
+    def put_account_configuration(
+        self, days_before_expiry: int, idempotency_token: str
+    ) -> None:
+        if idempotency_token is not None:
+            arn = self._get_arn_from_idempotency_token(idempotency_token)
+            if arn:
+                return
+
+        if days_before_expiry < 1 or days_before_expiry > 90:
+            raise AWSValidationException("DaysBeforeExpiry must be between 1 and 90")
+
+        self._account_config = AccountConfiguration(days_before_expiry)
+        if idempotency_token is not None:
+            self._set_idempotency_token_arn(idempotency_token, "account_config")
+
 
 acm_backends = BackendDict(AWSCertificateManagerBackend, "acm")
