@@ -126,6 +126,16 @@ class AthenaResponse(BaseResponse):
             }
         )
 
+    def list_capacity_reservations(self) -> str:
+        capacity_reservations = self.athena_backend.list_capacity_reservations()
+        return json.dumps({"CapacityReservations": capacity_reservations})
+
+    def update_capacity_reservation(self) -> str:
+        name = self._get_param("Name")
+        target_dpus = self._get_param("TargetDpus")
+        self.athena_backend.update_capacity_reservation(name, target_dpus)
+        return "{}"
+
     def get_query_results(self) -> str:
         exec_id = self._get_param("QueryExecutionId")
         result = self.athena_backend.get_query_results(exec_id)
@@ -181,6 +191,13 @@ class AthenaResponse(BaseResponse):
             {"DataCatalogsSummary": self.athena_backend.list_data_catalogs()}
         )
 
+    def list_tags_for_resource(self) -> Union[Tuple[str, Dict[str, int]], str]:
+        resource_arn = self._get_param("ResourceARN")
+        tags = self.athena_backend.list_tags_for_resource(resource_arn)
+        if not tags:
+            return self.error(f"Athena Resource, {resource_arn} Does Not Exist", 400)
+        return json.dumps(tags)
+
     def get_data_catalog(self) -> str:
         name = self._get_param("Name")
         return json.dumps({"DataCatalog": self.athena_backend.get_data_catalog(name)})
