@@ -1,22 +1,23 @@
-import datetime
 import enum
-import json
-import os
 import re
 import time
 import typing
 from collections import OrderedDict
 from typing import Any, Dict, List, Optional, Set, Tuple
 
-from jose import jws
+from joserfc import jwk, jwt
 
-from moto.core import BackendDict, BaseBackend, BaseModel
+from moto.core.base_backend import BackendDict, BaseBackend
+from moto.core.common_models import BaseModel
 from moto.core.utils import utcnow
 from moto.moto_api._internal import mock_random as random
 from moto.utilities.paginator import paginate
-from moto.utilities.utils import md5_hash
+from moto.utilities.utils import get_partition, load_resource, md5_hash
 
-from ..settings import get_cognito_idp_user_pool_id_strategy
+from ..settings import (
+    get_cognito_idp_user_pool_client_id_strategy,
+    get_cognito_idp_user_pool_id_strategy,
+)
 from .exceptions import (
     AliasExistsException,
     ExpiredCodeException,
@@ -32,7 +33,6 @@ from .exceptions import (
 from .utils import (
     PAGINATION_MODEL,
     check_secret_hash,
-    create_id,
     expand_attrs,
     flatten_attrs,
     generate_id,
@@ -63,7 +63,6 @@ class AuthFlow(str, enum.Enum):
 
 
 class CognitoIdpUserPoolAttribute(BaseModel):
-
     STANDARD_SCHEMA = {
         "sub": {
             "AttributeDataType": "String",
@@ -384,7 +383,6 @@ DEFAULT_USER_POOL_CONFIG: Dict[str, Any] = {
 
 
 class CognitoIdpUserPool(BaseModel):
-
     MAX_ID_LENGTH = 55
 
     def __init__(
@@ -397,7 +395,7 @@ class CognitoIdpUserPool(BaseModel):
             get_cognito_idp_user_pool_id_strategy(), region, name, extended_config
         )
         self.id = f"{self.region}_{user_pool_id}"[: self.MAX_ID_LENGTH]
-        self.arn = f"arn:aws:cognito-idp:{self.region}:{account_id}:userpool/{self.id}"
+        self.arn = f"arn:{get_partition(region)}:cognito-idp:{region}:{account_id}:userpool/{self.id}"
 
         self.name = name
         self.status = None
@@ -407,7 +405,7 @@ class CognitoIdpUserPool(BaseModel):
         self.creation_date = utcnow()
         self.last_modified_date = utcnow()
 
-        self.mfa_config = "OFF"
+        self.mfa_config = extended_config.get("MfaConfiguration") or "OFF"
         self.sms_mfa_config: Optional[Dict[str, Any]] = None
         self.token_mfa_config: Optional[Dict[str, bool]] = None
 
@@ -425,10 +423,10 @@ class CognitoIdpUserPool(BaseModel):
                 standard_attribute_name,
                 standard_attribute_schema,
             ) in CognitoIdpUserPoolAttribute.STANDARD_SCHEMA.items():
-                self.schema_attributes[
-                    standard_attribute_name
-                ] = CognitoIdpUserPoolAttribute(
-                    standard_attribute_name, False, standard_attribute_schema
+                self.schema_attributes[standard_attribute_name] = (
+                    CognitoIdpUserPoolAttribute(
+                        standard_attribute_name, False, standard_attribute_schema
+                    )
                 )
 
         self.clients: Dict[str, CognitoIdpUserPoolClient] = OrderedDict()
@@ -436,14 +434,12 @@ class CognitoIdpUserPool(BaseModel):
         self.groups: Dict[str, CognitoIdpGroup] = OrderedDict()
         self.users: Dict[str, CognitoIdpUser] = OrderedDict()
         self.resource_servers: Dict[str, CognitoResourceServer] = OrderedDict()
-        self.refresh_tokens: Dict[str, Optional[Tuple[str, str]]] = {}
+        self.refresh_tokens: Dict[str, Optional[Tuple[str, str, str]]] = {}
         self.access_tokens: Dict[str, Tuple[str, str]] = {}
         self.id_tokens: Dict[str, Tuple[str, str]] = {}
 
-        with open(
-            os.path.join(os.path.dirname(__file__), "resources/jwks-private.json")
-        ) as f:
-            self.json_web_key = json.loads(f.read())
+        jwks_file = load_resource(__name__, "resources/jwks-private.json")
+        self.json_web_key = jwk.RSAKey.import_key(jwks_file)
 
     @property
     def backend(self) -> "CognitoIdpBackend":
@@ -484,8 +480,8 @@ class CognitoIdpUserPool(BaseModel):
             "Arn": self.arn,
             "Name": self.name,
             "Status": self.status,
-            "CreationDate": time.mktime(self.creation_date.timetuple()),
-            "LastModifiedDate": time.mktime(self.last_modified_date.timetuple()),
+            "CreationDate": self.creation_date,
+            "LastModifiedDate": self.last_modified_date,
             "MfaConfiguration": self.mfa_config,
             "EstimatedNumberOfUsers": len(self.users),
         }
@@ -539,13 +535,28 @@ class CognitoIdpUserPool(BaseModel):
             "token_use": token_use,
             "auth_time": now,
             "exp": now + expires_in,
-            "username" if token_use == "access" else "cognito:username": username,
+            "jti": str(random.uuid4()),
         }
+        username_is_email = "email" in self.extended_config.get(
+            "UsernameAttributes", []
+        )
+        if token_use == "access":
+            if username_is_email:
+                payload["username"] = payload["sub"]
+            else:
+                payload["username"] = username
+        if token_use == "id":
+            if username_is_email:
+                payload["cognito:username"] = payload["sub"]
+                payload["email"] = username
+            else:
+                payload["cognito:username"] = username
+
         payload.update(extra_data or {})
-        headers = {"kid": "dummy"}  # KID as present in jwks-public.json
+        headers = {"kid": "dummy", "alg": "RS256"}  # KID as present in jwks-public.json
 
         return (
-            jws.sign(payload, self.json_web_key, headers, algorithm="RS256"),
+            jwt.encode(headers, payload, self.json_web_key),
             expires_in,
         )
 
@@ -565,8 +576,14 @@ class CognitoIdpUserPool(BaseModel):
         for attribute in attributes:
             self.schema_attributes[attribute.name] = attribute
 
-    def create_id_token(self, client_id: str, username: str) -> Tuple[str, int]:
+    def create_id_token(
+        self, client_id: str, username: str, origin_jti: str
+    ) -> Tuple[str, int]:
+        """
+        :returns: (id_token, expires_in)
+        """
         extra_data = self.get_user_extra_data_by_client_id(client_id, username)
+        extra_data["origin_jti"] = origin_jti
         user = self._get_user(username)
         for attr in user.attributes:
             if attr["Name"].startswith("custom:"):
@@ -579,13 +596,25 @@ class CognitoIdpUserPool(BaseModel):
         self.id_tokens[id_token] = (client_id, username)
         return id_token, expires_in
 
-    def create_refresh_token(self, client_id: str, username: str) -> str:
+    def create_refresh_token(self, client_id: str, username: str) -> Tuple[str, str]:
+        """
+        :returns: (refresh_token, origin_jti)
+        """
         refresh_token = str(random.uuid4())
-        self.refresh_tokens[refresh_token] = (client_id, username)
-        return refresh_token
+        origin_jti = str(random.uuid4())
+        self.refresh_tokens[refresh_token] = (client_id, username, origin_jti)
+        return refresh_token, origin_jti
 
-    def create_access_token(self, client_id: str, username: str) -> Tuple[str, int]:
-        extra_data = {}
+    def create_access_token(
+        self, client_id: str, username: str, origin_jti: str
+    ) -> Tuple[str, int]:
+        """
+        :returns: (access_token, expires_in)
+        """
+        extra_data: Dict[str, Any] = {
+            "origin_jti": origin_jti,
+            "scope": "aws.cognito.signin.user.admin",
+        }
         user = self._get_user(username)
         if len(user.groups) > 0:
             extra_data["cognito:groups"] = [group.group_name for group in user.groups]
@@ -602,12 +631,14 @@ class CognitoIdpUserPool(BaseModel):
         res = self.refresh_tokens[refresh_token]
         if res is None:
             raise NotAuthorizedError(refresh_token)
-        client_id, username = res
+        client_id, username, origin_jti = res
         if not username:
             raise NotAuthorizedError(refresh_token)
 
-        access_token, expires_in = self.create_access_token(client_id, username)
-        id_token, _ = self.create_id_token(client_id, username)
+        access_token, expires_in = self.create_access_token(
+            client_id, username, origin_jti=origin_jti
+        )
+        id_token, _ = self.create_id_token(client_id, username, origin_jti=origin_jti)
         return access_token, id_token, expires_in
 
     def get_user_extra_data_by_client_id(
@@ -631,11 +662,10 @@ class CognitoIdpUserPool(BaseModel):
         for token, token_tuple in list(self.refresh_tokens.items()):
             if token_tuple is None:
                 continue
-            _, logged_in_user = token_tuple
+            _, logged_in_user, _ = token_tuple
             if username == logged_in_user:
                 self.refresh_tokens[token] = None
-        for access_token, token_tuple in list(self.access_tokens.items()):
-            _, logged_in_user = token_tuple
+        for access_token, (_, logged_in_user) in list(self.access_tokens.items()):
             if username == logged_in_user:
                 self.access_tokens.pop(access_token)
 
@@ -677,6 +707,8 @@ class CognitoIdpUserPoolDomain(BaseModel):
 
 
 class CognitoIdpUserPoolClient(BaseModel):
+    MAX_ID_LENGTH = 26
+
     def __init__(
         self,
         user_pool_id: str,
@@ -684,7 +716,12 @@ class CognitoIdpUserPoolClient(BaseModel):
         extended_config: Optional[Dict[str, Any]],
     ):
         self.user_pool_id = user_pool_id
-        self.id = create_id()
+        self.id = generate_id(
+            get_cognito_idp_user_pool_client_id_strategy(),
+            user_pool_id,
+            generate_secret,
+            extended_config,
+        )[: self.MAX_ID_LENGTH]
         self.secret = str(random.uuid4())
         self.generate_secret = generate_secret or False
         # Some default values - may be overridden by the user
@@ -731,8 +768,8 @@ class CognitoIdpIdentityProvider(BaseModel):
         return {
             "ProviderName": self.name,
             "ProviderType": self.extended_config.get("ProviderType"),
-            "CreationDate": time.mktime(self.creation_date.timetuple()),
-            "LastModifiedDate": time.mktime(self.last_modified_date.timetuple()),
+            "CreationDate": self.creation_date,
+            "LastModifiedDate": self.last_modified_date,
         }
 
     def to_json(self, extended: bool = False) -> Dict[str, Any]:
@@ -757,7 +794,7 @@ class CognitoIdpGroup(BaseModel):
         self.description = description or ""
         self.role_arn = role_arn
         self.precedence = precedence
-        self.last_modified_date = datetime.datetime.now()
+        self.last_modified_date = utcnow()
         self.creation_date = self.last_modified_date
 
         # Users who are members of this group.
@@ -776,7 +813,7 @@ class CognitoIdpGroup(BaseModel):
             self.role_arn = role_arn
         if precedence is not None:
             self.precedence = precedence
-        self.last_modified_date = datetime.datetime.now()
+        self.last_modified_date = utcnow()
 
     def to_json(self) -> Dict[str, Any]:
         return {
@@ -785,8 +822,8 @@ class CognitoIdpGroup(BaseModel):
             "Description": self.description,
             "RoleArn": self.role_arn,
             "Precedence": self.precedence,
-            "LastModifiedDate": time.mktime(self.last_modified_date.timetuple()),
-            "CreationDate": time.mktime(self.creation_date.timetuple()),
+            "LastModifiedDate": self.last_modified_date,
+            "CreationDate": self.creation_date,
         }
 
 
@@ -828,8 +865,8 @@ class CognitoIdpUser(BaseModel):
             "UserPoolId": self.user_pool_id,
             "Username": self.username,
             "UserStatus": self.status,
-            "UserCreateDate": time.mktime(self.create_date.timetuple()),
-            "UserLastModifiedDate": time.mktime(self.last_modified_date.timetuple()),
+            "UserCreateDate": self.create_date,
+            "UserLastModifiedDate": self.last_modified_date,
         }
 
     # list_users brings back "Attributes" while admin_get_user brings back "UserAttributes".
@@ -868,6 +905,7 @@ class CognitoIdpUser(BaseModel):
         flat_attributes.update(flatten_attrs(new_attributes))
         self.attribute_lookup = flat_attributes
         self.attributes = expand_attrs(flat_attributes)
+        self.last_modified_date = utcnow()
 
     def delete_attributes(self, attrs_to_delete: List[str]) -> None:
         flat_attributes = flatten_attrs(self.attributes)
@@ -890,6 +928,7 @@ class CognitoIdpUser(BaseModel):
             )
         self.attribute_lookup = flat_attributes
         self.attributes = expand_attrs(flat_attributes)
+        self.last_modified_date = utcnow()
 
 
 class CognitoResourceServer(BaseModel):
@@ -931,13 +970,14 @@ class CognitoIdpBackend(BaseBackend):
     For example, a single initialization before the start of integration tests.
 
     This behavior can be enabled by passing the environment variable: MOTO_COGNITO_IDP_USER_POOL_ID_STRATEGY=HASH.
+    Passing MOTO_COGNITO_IDP_USER_POOL_CLIENT_ID_STRATEGY=HASH enables the same logic for user pool clients.
     """
 
     def __init__(self, region_name: str, account_id: str):
         super().__init__(region_name, account_id)
         self.user_pools: Dict[str, CognitoIdpUserPool] = OrderedDict()
         self.user_pool_domains: Dict[str, CognitoIdpUserPoolDomain] = OrderedDict()
-        self.sessions: Dict[str, CognitoIdpUserPool] = {}
+        self.sessions: Dict[str, Tuple[str, CognitoIdpUserPool]] = {}
 
     # User pool
     def create_user_pool(
@@ -972,7 +1012,7 @@ class CognitoIdpBackend(BaseBackend):
             "MfaConfiguration": user_pool.mfa_config,
         }
 
-    @paginate(pagination_model=PAGINATION_MODEL)  # type: ignore[misc]
+    @paginate(pagination_model=PAGINATION_MODEL)
     def list_user_pools(self) -> List[CognitoIdpUserPool]:
         return list(self.user_pools.values())
 
@@ -1045,7 +1085,7 @@ class CognitoIdpBackend(BaseBackend):
         user_pool.clients[user_pool_client.id] = user_pool_client
         return user_pool_client
 
-    @paginate(pagination_model=PAGINATION_MODEL)  # type: ignore[misc]
+    @paginate(pagination_model=PAGINATION_MODEL)
     def list_user_pool_clients(
         self, user_pool_id: str
     ) -> List[CognitoIdpUserPoolClient]:
@@ -1094,7 +1134,7 @@ class CognitoIdpBackend(BaseBackend):
         user_pool.identity_providers[name] = identity_provider
         return identity_provider
 
-    @paginate(pagination_model=PAGINATION_MODEL)  # type: ignore[misc]
+    @paginate(pagination_model=PAGINATION_MODEL)
     def list_identity_providers(
         self, user_pool_id: str
     ) -> List[CognitoIdpIdentityProvider]:
@@ -1162,7 +1202,7 @@ class CognitoIdpBackend(BaseBackend):
 
         return user_pool.groups[group_name]
 
-    @paginate(pagination_model=PAGINATION_MODEL)  # type: ignore[misc]
+    @paginate(pagination_model=PAGINATION_MODEL)
     def list_groups(self, user_pool_id: str) -> List[CognitoIdpGroup]:
         user_pool = self.describe_user_pool(user_pool_id)
 
@@ -1203,7 +1243,7 @@ class CognitoIdpBackend(BaseBackend):
         group.users.add(user)
         user.groups.add(group)
 
-    @paginate(pagination_model=PAGINATION_MODEL)  # type: ignore[misc]
+    @paginate(pagination_model=PAGINATION_MODEL)
     def list_users_in_group(
         self, user_pool_id: str, group_name: str
     ) -> List[CognitoIdpUser]:
@@ -1211,6 +1251,7 @@ class CognitoIdpBackend(BaseBackend):
         group = self.get_group(user_pool_id, group_name)
         return list(filter(lambda user: user in group.users, user_pool.users.values()))
 
+    @paginate(pagination_model=PAGINATION_MODEL)
     def admin_list_groups_for_user(
         self, user_pool_id: str, username: str
     ) -> List[CognitoIdpGroup]:
@@ -1341,11 +1382,55 @@ class CognitoIdpBackend(BaseBackend):
                 return user
         raise NotAuthorizedError("Invalid token")
 
-    @paginate(pagination_model=PAGINATION_MODEL)  # type: ignore[misc]
-    def list_users(self, user_pool_id: str) -> List[CognitoIdpUser]:
+    @paginate(pagination_model=PAGINATION_MODEL)
+    def list_users(self, user_pool_id: str, filt: str) -> List[CognitoIdpUser]:
         user_pool = self.describe_user_pool(user_pool_id)
+        users = list(user_pool.users.values())
+        if filt:
+            inherent_attributes: Dict[str, Any] = {
+                "cognito:user_status": lambda u: u.status,
+                "status": lambda u: "Enabled" if u.enabled else "Disabled",
+                "username": lambda u: u.username,
+            }
+            comparisons: Dict[str, Any] = {
+                "=": lambda x, y: x == y,
+                "^=": lambda x, y: x.startswith(y),
+            }
+            allowed_attributes = [
+                "username",
+                "email",
+                "phone_number",
+                "name",
+                "given_name",
+                "family_name",
+                "preferred_username",
+                "cognito:user_status",
+                "status",
+                "sub",
+            ]
 
-        return list(user_pool.users.values())
+            match = re.match(r"([\w:]+)\s*(=|\^=)\s*\"(.*)\"", filt)
+            if match:
+                name, op, value = match.groups()
+            else:
+                raise InvalidParameterException("Error while parsing filter")
+            if name not in allowed_attributes:
+                raise InvalidParameterException(f"Invalid search attribute: {name}")
+            compare = comparisons[op]
+            users = [
+                user
+                for user in users
+                if [
+                    attr
+                    for attr in user.attributes
+                    if attr["Name"] == name and compare(attr["Value"], value)
+                ]
+                or (
+                    name in inherent_attributes
+                    and compare(inherent_attributes[name](user), value)
+                )
+            ]
+        return users
 
     def admin_disable_user(self, user_pool_id: str, username: str) -> None:
         user = self.admin_get_user(user_pool_id, username)
@@ -1371,19 +1456,20 @@ class CognitoIdpBackend(BaseBackend):
         client: CognitoIdpUserPoolClient,
         username: str,
     ) -> Dict[str, Dict[str, Any]]:
-        refresh_token = user_pool.create_refresh_token(client.id, username)
+        refresh_token, _ = user_pool.create_refresh_token(client.id, username)
         access_token, id_token, expires_in = user_pool.create_tokens_from_refresh_token(
             refresh_token
         )
 
         return {
+            "ChallengeParameters": {},
             "AuthenticationResult": {
                 "IdToken": id_token,
                 "AccessToken": access_token,
                 "RefreshToken": refresh_token,
                 "ExpiresIn": expires_in,
                 "TokenType": "Bearer",
-            }
+            },
         }
 
     def _validate_auth_flow(
@@ -1444,7 +1530,7 @@ class CognitoIdpBackend(BaseBackend):
                 UserStatus.RESET_REQUIRED,
             ]:
                 session = str(random.uuid4())
-                self.sessions[session] = user_pool
+                self.sessions[session] = (username, user_pool)
 
                 return {
                     "ChallengeName": "NEW_PASSWORD_REQUIRED",
@@ -1457,7 +1543,7 @@ class CognitoIdpBackend(BaseBackend):
                 and user.preferred_mfa_setting == "SOFTWARE_TOKEN_MFA"
             ):
                 session = str(random.uuid4())
-                self.sessions[session] = user_pool
+                self.sessions[session] = (username, user_pool)
 
                 return {
                     "ChallengeName": "SOFTWARE_TOKEN_MFA",
@@ -1465,6 +1551,16 @@ class CognitoIdpBackend(BaseBackend):
                     "Session": session,
                 }
 
+            if user.sms_mfa_enabled and user.preferred_mfa_setting == "SMS_MFA":
+                session = str(random.uuid4())
+                self.sessions[session] = (username, user_pool)
+
+                return {
+                    "ChallengeName": "SMS_MFA",
+                    "ChallengeParameters": {},
+                    "Session": session,
+                }
+
             return self._log_user_in(user_pool, client, username)
         elif auth_flow in (AuthFlow.REFRESH_TOKEN, AuthFlow.REFRESH_TOKEN_AUTH):
             refresh_token: str = auth_parameters.get("REFRESH_TOKEN")  # type: ignore[assignment]
@@ -1513,9 +1609,9 @@ class CognitoIdpBackend(BaseBackend):
         if challenge_name == "PASSWORD_VERIFIER":
             session = challenge_responses.get("PASSWORD_CLAIM_SECRET_BLOCK")  # type: ignore[assignment]
 
-        user_pool = self.sessions.get(session)
-        if not user_pool:
+        if session not in self.sessions:
             raise ResourceNotFoundError(session)
+        _, user_pool = self.sessions[session]
 
         client = user_pool.clients.get(client_id)
         if not client:
@@ -1531,8 +1627,26 @@ class CognitoIdpBackend(BaseBackend):
 
             user.password = new_password
             user.status = UserStatus.CONFIRMED
-            del self.sessions[session]
 
+            if user_pool.mfa_config == "ON":
+                mfas_can_setup = []
+                if user_pool.token_mfa_config == {"Enabled": True}:
+                    mfas_can_setup.append("SOFTWARE_TOKEN_MFA")
+                if user_pool.sms_mfa_config:
+                    mfas_can_setup.append("SMS_MFA")
+
+                if (
+                    mfas_can_setup
+                    and not user.software_token_mfa_enabled
+                    and not user.sms_mfa_enabled
+                ):
+                    return {
+                        "ChallengeName": "MFA_SETUP",
+                        "ChallengeParameters": {"MFAS_CAN_SETUP": mfas_can_setup},
+                        "Session": session,
+                    }
+
+            del self.sessions[session]
             return self._log_user_in(user_pool, client, username)
         elif challenge_name == "PASSWORD_VERIFIER":
             username: str = challenge_responses.get("USERNAME")  # type: ignore[no-redef]
@@ -1552,7 +1666,29 @@ class CognitoIdpBackend(BaseBackend):
             if not timestamp:
                 raise ResourceNotFoundError(timestamp)
 
-            if user.software_token_mfa_enabled:
+            if user.status == UserStatus.FORCE_CHANGE_PASSWORD:
+                return {
+                    "ChallengeName": "NEW_PASSWORD_REQUIRED",
+                    "ChallengeParameters": {
+                        "USERNAME": username,
+                    },
+                    "Session": session,
+                }
+            if user_pool.mfa_config == "ON" and not user.token_verified:
+                mfas_can_setup = []
+                if user_pool.token_mfa_config == {"Enabled": True}:
+                    mfas_can_setup.append("SOFTWARE_TOKEN_MFA")
+                if user_pool.sms_mfa_config:
+                    mfas_can_setup.append("SMS_MFA")
+
+                return {
+                    "ChallengeName": "MFA_SETUP",
+                    "ChallengeParameters": {"MFAS_CAN_SETUP": mfas_can_setup},
+                    "Session": session,
+                }
+            if user.software_token_mfa_enabled or (
+                user_pool.token_mfa_config == {"Enabled": True} and user.token_verified
+            ):
                 return {
                     "ChallengeName": "SOFTWARE_TOKEN_MFA",
                     "Session": session,
@@ -1566,24 +1702,15 @@ class CognitoIdpBackend(BaseBackend):
                     "ChallengeParameters": {},
                 }
 
-            if user.status == UserStatus.FORCE_CHANGE_PASSWORD:
-                return {
-                    "ChallengeName": "NEW_PASSWORD_REQUIRED",
-                    "ChallengeParameters": {
-                        "USERNAME": username,
-                    },
-                    "Session": session,
-                }
-
             del self.sessions[session]
             return self._log_user_in(user_pool, client, username)
-        elif challenge_name == "SOFTWARE_TOKEN_MFA":
+        elif challenge_name == "SOFTWARE_TOKEN_MFA" or challenge_name == "SMS_MFA":
             username: str = challenge_responses.get("USERNAME")  # type: ignore[no-redef]
             self.admin_get_user(user_pool.id, username)
 
-            software_token_mfa_code = challenge_responses.get("SOFTWARE_TOKEN_MFA_CODE")
-            if not software_token_mfa_code:
-                raise ResourceNotFoundError(software_token_mfa_code)
+            mfa_code = challenge_responses.get(f"{challenge_name}_CODE")
+            if not mfa_code:
+                raise ResourceNotFoundError(mfa_code)
 
             if client.generate_secret:
                 secret_hash = challenge_responses.get("SECRET_HASH")
@@ -1595,6 +1722,10 @@ class CognitoIdpBackend(BaseBackend):
             del self.sessions[session]
             return self._log_user_in(user_pool, client, username)
 
+        elif challenge_name == "MFA_SETUP":
+            username, user_pool = self.sessions[session]
+            return self._log_user_in(user_pool, client, username)
+
         else:
             return {}
 
@@ -1648,13 +1779,14 @@ class CognitoIdpBackend(BaseBackend):
             )
             user.confirmation_code = confirmation_code
 
-        code_delivery_details = {
-            "Destination": username + "@h***.com"
-            if not user
-            else user.attribute_lookup.get("email", username + "@h***.com"),
-            "DeliveryMedium": "EMAIL",
-            "AttributeName": "email",
-        }
+        code_delivery_details = self._get_code_delivery_details(
+            recovery_settings, user, username
+        )
+        return confirmation_code, {"CodeDeliveryDetails": code_delivery_details}
+
+    def _get_code_delivery_details(
+        self, recovery_settings: Any, user: Optional[CognitoIdpUser], username: str
+    ) -> Dict[str, str]:
         selected_recovery = min(
             recovery_settings["RecoveryMechanisms"],
             key=lambda recovery_mechanism: recovery_mechanism["Priority"],
@@ -1662,14 +1794,24 @@ class CognitoIdpBackend(BaseBackend):
         if selected_recovery["Name"] == "admin_only":
             raise NotAuthorizedError("Contact administrator to reset password.")
         if selected_recovery["Name"] == "verified_phone_number":
-            code_delivery_details = {
-                "Destination": "+*******9934"
-                if not user
-                else user.attribute_lookup.get("phone_number", "+*******9934"),
+            number = "+*******9934"
+            if user and "phone_number" in user.attribute_lookup:
+                number = user.attribute_lookup["phone_number"]
+            return {
+                "Destination": number,
                 "DeliveryMedium": "SMS",
                 "AttributeName": "phone_number",
             }
-        return confirmation_code, {"CodeDeliveryDetails": code_delivery_details}
+        else:
+            email = username + "@h***.com"
+            if user and "email" in user.attribute_lookup:
+                first, second = user.attribute_lookup["email"].split("@")
+                email = f"{first[0]}***@{second[0]}***"
+            return {
+                "Destination": email,
+                "DeliveryMedium": "EMAIL",
+                "AttributeName": "email",
+            }
 
     def change_password(
         self, access_token: str, previous_password: str, proposed_password: str
@@ -1758,7 +1900,7 @@ class CognitoIdpBackend(BaseBackend):
 
         return resource_server
 
-    @paginate(pagination_model=PAGINATION_MODEL)  # type: ignore[misc]
+    @paginate(pagination_model=PAGINATION_MODEL)
     def list_resource_servers(self, user_pool_id: str) -> List[CognitoResourceServer]:
         user_pool = self.user_pools[user_pool_id]
         resource_servers = list(user_pool.resource_servers.values())
@@ -1770,7 +1912,7 @@ class CognitoIdpBackend(BaseBackend):
         username: str,
         password: str,
         attributes: List[Dict[str, str]],
-    ) -> CognitoIdpUser:
+    ) -> Tuple[CognitoIdpUser, Any]:
         user_pool = None
         for p in self.user_pools.values():
             if client_id in p.clients:
@@ -1832,7 +1974,27 @@ class CognitoIdpBackend(BaseBackend):
             status=UserStatus.UNCONFIRMED,
         )
         user_pool.users[user.username] = user
-        return user
+
+        has_email = "email" in user.attribute_lookup
+        has_phone = "phone_number" in user.attribute_lookup
+        verified_attributes = user_pool.extended_config.get(
+            "AutoVerifiedAttributes", []
+        )
+        email_verified = (
+            "email_verified" in user.attribute_lookup or "email" in verified_attributes
+        )
+        phone_verified = (
+            "phone_number_verified" in user.attribute_lookup
+            or "phone_number" in verified_attributes
+        )
+        if (has_email and email_verified) or (has_phone and phone_verified):
+            recovery_settings = user_pool.extended_config["AccountRecoverySetting"]
+            details = self._get_code_delivery_details(
+                recovery_settings=recovery_settings, user=user, username=user.username
+            )
+            return user, details
+        else:
+            return user, None
 
     def confirm_sign_up(self, client_id: str, username: str) -> str:
         user_pool = None
@@ -1892,7 +2054,7 @@ class CognitoIdpBackend(BaseBackend):
                 raise UserNotConfirmedException("User is not confirmed.")
 
             session = str(random.uuid4())
-            self.sessions[session] = user_pool
+            self.sessions[session] = (username, user_pool)
 
             return {
                 "ChallengeName": "PASSWORD_VERIFIER",
@@ -1924,7 +2086,7 @@ class CognitoIdpBackend(BaseBackend):
                 raise UserNotConfirmedException("User is not confirmed.")
 
             session = str(random.uuid4())
-            self.sessions[session] = user_pool
+            self.sessions[session] = (username, user_pool)
 
             if user.status is UserStatus.FORCE_CHANGE_PASSWORD:
                 return {
@@ -1933,11 +2095,32 @@ class CognitoIdpBackend(BaseBackend):
                     "Session": session,
                 }
 
-            access_token, expires_in = user_pool.create_access_token(
+            if (
+                user.software_token_mfa_enabled
+                and user.preferred_mfa_setting == "SOFTWARE_TOKEN_MFA"
+            ) or (user_pool.mfa_config == "ON" and user.token_verified):
+                return {
+                    "ChallengeName": "SOFTWARE_TOKEN_MFA",
+                    "ChallengeParameters": {},
+                    "Session": session,
+                }
+
+            if user.sms_mfa_enabled and user.preferred_mfa_setting == "SMS_MFA":
+                return {
+                    "ChallengeName": "SMS_MFA",
+                    "ChallengeParameters": {},
+                    "Session": session,
+                }
+
+            new_refresh_token, origin_jti = user_pool.create_refresh_token(
                 client_id, username
             )
-            id_token, _ = user_pool.create_id_token(client_id, username)
-            new_refresh_token = user_pool.create_refresh_token(client_id, username)
+            access_token, expires_in = user_pool.create_access_token(
+                client_id, username, origin_jti=origin_jti
+            )
+            id_token, _ = user_pool.create_id_token(
+                client_id, username, origin_jti=origin_jti
+            )
 
             return {
                 "AuthenticationResult": {
@@ -1953,11 +2136,11 @@ class CognitoIdpBackend(BaseBackend):
             if not refresh_token:
                 raise ResourceNotFoundError(refresh_token)
 
-            res = user_pool.refresh_tokens[refresh_token]
+            res = user_pool.refresh_tokens.get(refresh_token)
             if res is None:
                 raise NotAuthorizedError("Refresh Token has been revoked")
 
-            client_id, username = res
+            client_id, username, _ = res
             if not username:
                 raise ResourceNotFoundError(username)
 
@@ -1986,20 +2169,40 @@ class CognitoIdpBackend(BaseBackend):
             # We shouldn't get here due to enum validation of auth_flow
             return None  # type: ignore[return-value]
 
-    def associate_software_token(self, access_token: str) -> Dict[str, str]:
+    def associate_software_token(
+        self, access_token: str, session: str
+    ) -> Dict[str, str]:
+        secret_code = "asdfasdfasdf"
+        if session:
+            if session in self.sessions:
+                return {"SecretCode": secret_code, "Session": session}
+            raise NotAuthorizedError(session)
+
         for user_pool in self.user_pools.values():
             if access_token in user_pool.access_tokens:
                 _, username = user_pool.access_tokens[access_token]
                 self.admin_get_user(user_pool.id, username)
 
-                return {"SecretCode": str(random.uuid4())}
+                return {"SecretCode": secret_code}
 
         raise NotAuthorizedError(access_token)
 
-    def verify_software_token(self, access_token: str) -> Dict[str, str]:
+    def verify_software_token(self, access_token: str, session: str) -> Dict[str, str]:
         """
         The parameter UserCode has not yet been implemented
         """
+        if session:
+            if session not in self.sessions:
+                raise ResourceNotFoundError(session)
+
+            username, user_pool = self.sessions[session]
+            user = self.admin_get_user(user_pool.id, username)
+            user.token_verified = True
+
+            session = str(random.uuid4())
+            self.sessions[session] = (username, user_pool)
+            return {"Status": "SUCCESS", "Session": session}
+
         for user_pool in self.user_pools.values():
             if access_token in user_pool.access_tokens:
                 _, username = user_pool.access_tokens[access_token]
@@ -2007,7 +2210,9 @@ class CognitoIdpBackend(BaseBackend):
 
                 user.token_verified = True
 
-                return {"Status": "SUCCESS"}
+                session = str(random.uuid4())
+                self.sessions[session] = (username, user_pool)
+                return {"Status": "SUCCESS", "Session": session}
 
         raise NotAuthorizedError(access_token)
 
@@ -2170,6 +2375,20 @@ class RegionAgnosticBackend:
                         return backend
         return cognitoidp_backends[self.account_id][self.region_name]
 
+    def _find_backend_by_access_token_or_session(
+        self, access_token: str, session: str
+    ) -> CognitoIdpBackend:
+        for account_specific_backends in cognitoidp_backends.values():
+            for region, backend in account_specific_backends.items():
+                if region == "global":
+                    continue
+                if session and session in backend.sessions:
+                    return backend
+                for p in backend.user_pools.values():
+                    if access_token and access_token in p.access_tokens:
+                        return backend
+        return cognitoidp_backends[self.account_id][self.region_name]
+
     def _find_backend_for_clientid(self, client_id: str) -> CognitoIdpBackend:
         for account_specific_backends in cognitoidp_backends.values():
             for region, backend in account_specific_backends.items():
@@ -2186,7 +2405,7 @@ class RegionAgnosticBackend:
         username: str,
         password: str,
         attributes: List[Dict[str, str]],
-    ) -> CognitoIdpUser:
+    ) -> Tuple[CognitoIdpUser, Any]:
         backend = self._find_backend_for_clientid(client_id)
         return backend.sign_up(client_id, username, password, attributes)
 
@@ -2228,6 +2447,33 @@ class RegionAgnosticBackend:
             session, client_id, challenge_name, challenge_responses
         )
 
+    def associate_software_token(
+        self, access_token: str, session: str
+    ) -> Dict[str, str]:
+        backend = self._find_backend_by_access_token_or_session(access_token, session)
+        return backend.associate_software_token(access_token, session)
+
+    def verify_software_token(self, access_token: str, session: str) -> Dict[str, str]:
+        backend = self._find_backend_by_access_token_or_session(access_token, session)
+        return backend.verify_software_token(access_token, session)
+
+    def set_user_mfa_preference(
+        self,
+        access_token: str,
+        software_token_mfa_settings: Dict[str, bool],
+        sms_mfa_settings: Dict[str, bool],
+    ) -> None:
+        backend = self._find_backend_by_access_token(access_token)
+        return backend.set_user_mfa_preference(
+            access_token, software_token_mfa_settings, sms_mfa_settings
+        )
+
+    def update_user_attributes(
+        self, access_token: str, attributes: List[Dict[str, str]]
+    ) -> None:
+        backend = self._find_backend_by_access_token(access_token)
+        return backend.update_user_attributes(access_token, attributes)
+
 
 cognitoidp_backends = BackendDict(CognitoIdpBackend, "cognito-idp")
 
