@@ -56,7 +56,6 @@ import abc
 import base64
 import calendar
 import json
-import warnings
 from dataclasses import dataclass
 from datetime import datetime
 from typing import (
@@ -68,13 +67,15 @@ from typing import (
     Optional,
     TypedDict,
     Union,
-    cast,
 )
 
 import xmltodict
 from botocore import xform_name
 from botocore.compat import formatdate
-from botocore.model import (
+from botocore.utils import is_json_value_header, parse_to_aware_datetime
+
+from moto.core.errors import ErrorLookupFactory, ErrorShape
+from moto.core.model import (
     ListShape,
     MapShape,
     OperationModel,
@@ -82,23 +83,11 @@ from botocore.model import (
     Shape,
     StructureShape,
 )
-from botocore.utils import is_json_value_header, parse_to_aware_datetime
-
 from moto.core.utils import MISSING, get_value
 
 Serialized = MutableMapping[str, Any]
 
-# These are common error codes that are *not* included in the service definitions.
-# For example:
-# https://docs.aws.amazon.com/emr/latest/APIReference/CommonErrors.html
-# https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/CommonErrors.html
-# TODO: Augment the service definitions with shape models for these errors.
-COMMON_ERROR_CODES = [
-    "InvalidParameterCombination",
-    "InvalidParameterValue",
-    "ValidationError",
-    "ValidationException",
-]
+error_lookup = ErrorLookupFactory()
 
 
 class ResponseDict(TypedDict):
@@ -112,36 +101,6 @@ class SerializationContext:
         self.request_id = request_id or "request-id"
 
 
-class ErrorShape(StructureShape):
-    _shape_model: dict[str, Any]
-
-    # Overriding super class property to keep mypy happy...
-    @property
-    def error_code(self) -> str:
-        code = str(super().error_code)
-        return code
-
-
-class ShapeHelpersMixin:
-    @staticmethod
-    def get_serialized_name(shape: Shape, default_name: str) -> str:
-        return shape.serialization.get("name", default_name)
-
-    @staticmethod
-    def is_flattened(shape: Shape) -> bool:
-        return shape.serialization.get("flattened", False)
-
-    @staticmethod
-    def is_http_header_trait(shape: Shape) -> bool:
-        return hasattr(shape, "serialization") and shape.serialization.get(
-            "location"
-        ) in ["header", "headers"]
-
-    @staticmethod
-    def is_not_bound_to_body(shape: Shape) -> bool:
-        return hasattr(shape, "serialization") and "location" in shape.serialization
-
-
 class TimestampSerializer:
     TIMESTAMP_FORMAT_ISO8601 = "iso8601"
     TIMESTAMP_FORMAT_RFC822 = "rfc822"
@@ -188,7 +147,7 @@ class TimestampSerializer:
         return final_value
 
 
-class HeaderSerializer(ShapeHelpersMixin):
+class HeaderSerializer:
     # https://smithy.io/2.0/spec/http-bindings.html#httpheader-serialization-rules
     DEFAULT_ENCODING = "utf-8"
     DEFAULT_TIMESTAMP_FORMAT = TimestampSerializer.TIMESTAMP_FORMAT_RFC822
@@ -226,7 +185,7 @@ class HeaderSerializer(ShapeHelpersMixin):
     def _serialize_type_map(
         self, serialized: Serialized, value: Any, shape: MapShape, _: str
     ) -> None:
-        header_prefix = self.get_serialized_name(shape, "")
+        header_prefix = shape.serialization.get("name", "")
         for key, val in value.items():
             full_key = header_prefix + key
             self._default_serialize(serialized, val, shape, full_key)
@@ -253,7 +212,7 @@ class HeaderSerializer(ShapeHelpersMixin):
         return base64.b64encode(value).strip().decode(self.DEFAULT_ENCODING)
 
 
-class ResponseSerializer(ShapeHelpersMixin):
+class ResponseSerializer:
     CONTENT_TYPE = "text"
     DEFAULT_ENCODING = "utf-8"
     DEFAULT_RESPONSE_CODE = 200
@@ -281,7 +240,8 @@ class ResponseSerializer(ShapeHelpersMixin):
             value_picker = DefaultAttributePicker()
         self._value_picker = value_picker
         self._timestamp_serializer = TimestampSerializer(self.DEFAULT_TIMESTAMP_FORMAT)
-        self.path = []
+        self.operation_name = str(operation_model.name)
+        self.path = [self.operation_name]
 
     def _create_default_response(self) -> ResponseDict:
         response_dict: ResponseDict = {
@@ -304,7 +264,8 @@ class ResponseSerializer(ShapeHelpersMixin):
         resp: ResponseDict,
         error: Exception,
     ) -> ResponseDict:
-        error_shape = self._get_error_shape(error)
+        error_shapes = error_lookup.for_service(self.service_model)
+        error_shape = error_shapes.from_exception(error)
         serialized_error = self.MAP_TYPE()
         self._serialize_error_metadata(serialized_error, error, error_shape)
         return self._serialized_error_to_response(
@@ -371,33 +332,6 @@ class ResponseSerializer(ShapeHelpersMixin):
         )
         return self._value_picker(context)
 
-    def _get_error_shape(self, error: Exception) -> ErrorShape:
-        error_code = getattr(error, "code", MISSING)
-        error_name = error.__class__.__name__
-        error_shapes = cast(list[ErrorShape], self.service_model.error_shapes)
-        for error_shape in error_shapes:
-            if error_shape.error_code == error_code:
-                break
-            if error_shape.name in [error_code, error_name]:
-                break
-        else:
-            error_shape = None
-        if error_shape is None:
-            service_id = self.service_model.metadata.get("serviceId")
-            if service_id and error_code not in COMMON_ERROR_CODES:
-                warning = f"{service_id} service model does not contain an error shape that matches code {error_code} from Exception({error_name})"
-                warnings.warn(warning)
-            generic_error_model = {
-                "exception": True,
-                "type": "structure",
-                "members": {},
-                "error": {
-                    "code": error_code,
-                },
-            }
-            error_shape = ErrorShape(error_name, generic_error_model)
-        return error_shape
-
     #
     # Default serializers for the various model Shape types.
     # These can be overridden in subclasses to provide protocol-specific implementations.
@@ -415,11 +349,11 @@ class ResponseSerializer(ShapeHelpersMixin):
         method(serialized, value, shape, key)
         self.path.pop()
 
-    @staticmethod
     def _default_serialize(
-        serialized: Serialized, value: Any, _: Shape, key: str
+        self, serialized: Serialized, value: Any, shape: Shape, key: str
     ) -> None:
-        serialized[key] = value
+        serialization_key = self.get_serialized_name(shape, key)
+        serialized[serialization_key] = value
 
     def _serialize_type_structure(
         self, serialized: Serialized, value: Any, shape: StructureShape, key: str
@@ -427,46 +361,39 @@ class ResponseSerializer(ShapeHelpersMixin):
         if value is None:
             return
         if key:
-            new_serialized = self.MAP_TYPE()
-            serialized[key] = new_serialized
-            serialized = new_serialized
+            wrapper: Any = self.MAP_TYPE()
+        else:
+            wrapper = serialized
         for member_key, member_shape in shape.members.items():
             setattr(member_shape, "parent", shape)
-            self._serialize_structure_member(
-                serialized, value, member_shape, member_key
-            )
+            self._serialize_structure_member(wrapper, value, member_shape, member_key)
+        if key:
+            self._default_serialize(serialized, wrapper, shape, key)
 
     def _serialize_structure_member(
         self, serialized: Serialized, value: Any, shape: Shape, key: str
     ) -> None:
         member_value = self.get_value(value, key, shape)
         if member_value is not None:
-            key_name = self.get_serialized_name(shape, key)
-            self._serialize(serialized, member_value, shape, key_name)
+            self._serialize(serialized, member_value, shape, key)
 
     def _serialize_type_map(
         self, serialized: Serialized, value: Any, shape: MapShape, key: str
     ) -> None:
-        map_list = []
-        if self.is_flattened(shape):
-            items_name = key
-            serialized[items_name] = map_list
-        else:
-            items_name = "entry"
-            serialized[key] = {items_name: map_list}
         key_shape = shape.key
         assert isinstance(key_shape, Shape)
         value_shape = shape.value
         assert isinstance(value_shape, Shape)
-        for key in value:
+        map_list = []
+        for k, v in value.items():
             wrapper = {"__current__": {}}
-            key_prefix = self.get_serialized_name(key_shape, "key")
-            value_prefix = self.get_serialized_name(value_shape, "value")
-            self._serialize(wrapper["__current__"], key, key_shape, key_prefix)
-            self._serialize(
-                wrapper["__current__"], value[key], value_shape, value_prefix
-            )
+            self._serialize(wrapper["__current__"], k, key_shape, "key")
+            self._serialize(wrapper["__current__"], v, value_shape, "value")
             map_list.append(wrapper["__current__"])
+        if shape.is_flattened:
+            self._default_serialize(serialized, map_list, shape, key)
+        else:
+            self._default_serialize(serialized, {"entry": map_list}, shape, key)
 
     def _serialize_type_timestamp(
         self, serialized: Serialized, value: Any, shape: Shape, key: str
@@ -498,6 +425,9 @@ class ResponseSerializer(ShapeHelpersMixin):
 
     _serialize_type_double = _serialize_type_float
 
+    def get_serialized_name(self, shape: Shape, default_name: str) -> str:
+        return shape.serialization.get("name", default_name)
+
 
 class BaseJSONSerializer(ResponseSerializer):
     APPLICATION_AMZ_JSON = "application/x-amz-json-{version}"
@@ -526,11 +456,20 @@ class BaseJSONSerializer(ResponseSerializer):
             "httpStatusCode", self.DEFAULT_ERROR_RESPONSE_CODE
         )
         resp["status_code"] = status_code
-        error_code = self._get_protocol_specific_error_code(shape.error_code)
+        error_code = self._get_protocol_specific_error_code(shape)
         resp["headers"]["X-Amzn-Errortype"] = error_code
         resp["headers"]["Content-Type"] = self._get_protocol_specific_content_type()
+        self._serialize_query_compatible_error_to_response(resp, shape)
         return resp
 
+    def _serialize_query_compatible_error_to_response(
+        self, resp: ResponseDict, shape: ErrorShape
+    ) -> None:
+        if "awsQueryCompatible" not in self.service_model.metadata:
+            return
+        fault = "Sender" if shape.is_sender_fault else "Receiver"
+        resp["headers"]["x-amzn-query-error"] = f"{shape.error_code};{fault}"
+
     def _get_protocol_specific_content_type(self) -> str:
         content_type = self.CONTENT_TYPE
         service_model = self.operation_model.service_model
@@ -542,12 +481,17 @@ class BaseJSONSerializer(ResponseSerializer):
 
     def _get_protocol_specific_error_code(
         self,
-        error_code: str,
+        error: ErrorShape,
     ) -> str:
         # https://smithy.io/2.0/aws/protocols/aws-json-1_1-protocol.html#operation-error-serialization
         service_metadata = self.operation_model.service_model.metadata
         json_version = service_metadata.get("jsonVersion")
-        prefix = service_metadata.get("targetPrefix")
+        error_code = error.name
+        prefix = (
+            error.namespace
+            or service_metadata.get("errorNamespace")
+            or service_metadata.get("targetPrefix")
+        )
         if json_version == "1.0" and prefix is not None:
             error_code = prefix + "#" + error_code
         return error_code
@@ -558,7 +502,7 @@ class BaseJSONSerializer(ResponseSerializer):
         error: Exception,
         shape: ErrorShape,
     ) -> None:
-        error_code = self._get_protocol_specific_error_code(shape.error_code)
+        error_code = self._get_protocol_specific_error_code(shape)
         serialized["__type"] = error_code
         message = getattr(error, "message", None) or str(error)
         if shape is not None:
@@ -574,7 +518,7 @@ class BaseJSONSerializer(ResponseSerializer):
         self, serialized: Serialized, value: Any, shape: MapShape, key: str
     ) -> None:
         map_obj = self.MAP_TYPE()
-        serialized[key] = map_obj
+        self._default_serialize(serialized, map_obj, shape, key)
         for sub_key, sub_value in value.items():
             assert isinstance(shape.value, Shape)  # mypy hint
             self._serialize(map_obj, sub_value, shape.value, sub_key)
@@ -583,7 +527,6 @@ class BaseJSONSerializer(ResponseSerializer):
         self, serialized: Serialized, value: Any, shape: ListShape, key: str
     ) -> None:
         list_obj = []
-        serialized[key] = list_obj
         for list_item in value:
             wrapper = {}
             # The JSON list serialization is the only case where we aren't
@@ -597,6 +540,7 @@ class BaseJSONSerializer(ResponseSerializer):
                 list_obj.append(wrapper[item_key])
             else:
                 list_obj.append(list_item)
+        self._default_serialize(serialized, list_obj, shape, key)
 
     def _serialize_type_structure(
         self, serialized: Serialized, value: Any, shape: StructureShape, key: str
@@ -662,9 +606,7 @@ class BaseXMLSerializer(ResponseSerializer):
         error: Exception,
         shape: ErrorShape,
     ) -> None:
-        at_fault = shape._shape_model.get("fault", False)
-        sender_fault = shape.metadata.get("error", {}).get("senderFault", False)
-        serialized["Type"] = "Receiver" if (at_fault and not sender_fault) else "Sender"
+        serialized["Type"] = "Sender" if shape.is_sender_fault else "Receiver"
         serialized["Code"] = shape.error_code
         message = getattr(error, "message", None)
         if message is not None:
@@ -708,20 +650,22 @@ class BaseXMLSerializer(ResponseSerializer):
     ) -> None:
         assert isinstance(shape.member, Shape)  # mypy hinting
         list_obj = []
-        if self.is_flattened(shape):
-            items_name = self.get_serialized_name(shape.member, key)
-            serialized[items_name] = list_obj
-        else:
-            items_name = self.get_serialized_name(shape.member, "member")
-            serialized[key] = {items_name: list_obj}
         for list_item in value:
             wrapper = {}
-            item_key = shape.member.name
-            self._serialize(wrapper, list_item, shape.member, item_key)
-            if item_key in wrapper and wrapper[item_key]:
-                list_obj.append(wrapper[item_key])
-        if not list_obj:
-            serialized[key] = ""
+            self._serialize(wrapper, list_item, shape.member, shape.member.name)
+            if wrapper:
+                item_key = self.get_serialized_name(shape.member, shape.member.name)
+                value = wrapper[item_key]
+                if value != {}:
+                    list_obj.append(value)
+        if not list_obj:  # empty list serialized as "" in XML
+            self._default_serialize(serialized, "", shape, key)
+            return
+        if shape.is_flattened:
+            self._default_serialize(serialized, list_obj, shape.member, key)
+        else:
+            items_name = self.get_serialized_name(shape.member, "member")
+            self._default_serialize(serialized, {items_name: list_obj}, shape, key)
 
     _serialize_type_long = _serialize_type_integer
 
@@ -795,8 +739,8 @@ class BaseRestSerializer(ResponseSerializer):
     def _serialize_structure_member(
         self, serialized: Serialized, value: Any, shape: Shape, key: str
     ) -> None:
-        if self.is_not_bound_to_body(shape):
-            if self.is_http_header_trait(shape) and "headers" in serialized:
+        if shape.is_not_bound_to_body:
+            if shape.is_http_header_trait and "headers" in serialized:
                 member_value = self.get_value(value, key, shape)
                 if member_value is not None:
                     key_name = self.get_serialized_name(shape, key)
@@ -870,6 +814,27 @@ class QuerySerializer(BaseXMLSerializer):
         resp["headers"]["Content-Type"] = self.CONTENT_TYPE
         return resp
 
+    def _serialize_type_map(
+        self, serialized: Serialized, value: Any, shape: MapShape, key: str
+    ) -> None:
+        key_shape = shape.key
+        assert isinstance(key_shape, Shape)
+        value_shape = shape.value
+        assert isinstance(value_shape, Shape)
+        map_list = []
+        for k, v in value.items():
+            # Query protocol does not serialize null values
+            if v is None:
+                continue
+            wrapper = {"__current__": {}}
+            self._serialize(wrapper["__current__"], k, key_shape, "key")
+            self._serialize(wrapper["__current__"], v, value_shape, "value")
+            map_list.append(wrapper["__current__"])
+        if shape.is_flattened:
+            self._default_serialize(serialized, map_list, shape, key)
+        else:
+            self._default_serialize(serialized, {"entry": map_list}, shape, key)
+
 
 class QueryJSONSerializer(QuerySerializer):
     """Specialized case for query protocol requests that contain ContentType=JSON parameter."""
@@ -995,6 +960,14 @@ SERIALIZERS = {
     "rest-json": RestJSONSerializer,
     "rest-xml": RestXMLSerializer,
 }
+SERVICE_SPECIFIC_SERIALIZERS = {}
+
+
+def get_serializer_class(service_name: str, protocol: str) -> type[ResponseSerializer]:
+    if service_name in SERVICE_SPECIFIC_SERIALIZERS:
+        if protocol in SERVICE_SPECIFIC_SERIALIZERS[service_name]:
+            return SERVICE_SPECIFIC_SERIALIZERS[service_name][protocol]
+    return SERIALIZERS[protocol]
 
 
 @dataclass
@@ -1036,9 +1009,10 @@ class AttributePicker(DefaultAttributePicker):
         else:
             value = None
         key_path = f"{context.key_path}.{context.key}"
-        if key_path in self.response_transformers:
-            transform = self.response_transformers[key_path]
-            value = transform(value)
+        for transform_path, transform in self.response_transformers.items():
+            if key_path.endswith(transform_path):
+                value = transform(value)
+                break
         return value
 
     def get_possible_keys(self, context: AttributePickerContext) -> Generator[str]:
