@@ -15,7 +15,6 @@ from moto.ec2.models.availability_zones_and_regions import Zone
 from ..exceptions import (
     DefaultSubnetAlreadyExistsInAvailabilityZoneError,
     DefaultVpcDoesNotExistError,
-    GenericInvalidParameterValueError,
     InvalidAvailabilityZoneError,
     InvalidCIDRBlockParameterError,
     InvalidParameterValueError,
@@ -44,18 +43,22 @@ class Subnet(TaggedEC2Resource, CloudFormationModel):
         availability_zone: Zone,
         default_for_az: str,
         map_public_ip_on_launch: str,
-        assign_ipv6_address_on_creation: bool = False,
+        ipv6_native: bool = False,
     ):
         self.ec2_backend = ec2_backend
         self.id = subnet_id
         self.vpc_id = vpc_id
         self.cidr_block = cidr_block
-        self.cidr = ipaddress.IPv4Network(str(self.cidr_block), strict=False)
+        self.cidr = (
+            ipaddress.IPv4Network(str(self.cidr_block), strict=False)
+            if self.cidr_block
+            else ipaddress.IPv6Network(ipv6_cidr_block)
+        )
         self._available_ip_addresses = self.cidr.num_addresses - 5
         self._availability_zone = availability_zone
         self.default_for_az = default_for_az
         self.map_public_ip_on_launch = map_public_ip_on_launch
-        self.assign_ipv6_address_on_creation = assign_ipv6_address_on_creation
+        self.assign_ipv6_address_on_creation = ipv6_native
         self.ipv6_cidr_block_associations: Dict[str, Dict[str, Any]] = {}
         if ipv6_cidr_block:
             self.attach_ipv6_cidr_block_associations(ipv6_cidr_block)
@@ -63,7 +66,7 @@ class Subnet(TaggedEC2Resource, CloudFormationModel):
         # Theory is we assign ip's as we go (as 16,777,214 usable IPs in a /8)
         self._subnet_ip_generator = self.cidr.hosts()
         self.reserved_ips = [
-            next(self._subnet_ip_generator) for _ in range(0, 3)
+            next(iter(self._subnet_ip_generator)) for _ in range(0, 3)
         ]  # Reserved by AWS
         self._unused_ips: Set[str] = (
             set()
@@ -72,7 +75,7 @@ class Subnet(TaggedEC2Resource, CloudFormationModel):
         self.state = "available"
 
         # Placeholder for response templates until Ipv6 support implemented.
-        self.ipv6_native = False
+        self.ipv6_native = ipv6_native
 
     @property
     def arn(self) -> str:
@@ -219,11 +222,11 @@ class Subnet(TaggedEC2Resource, CloudFormationModel):
         try:
             new_ip = str(self._unused_ips.pop())
         except KeyError:
-            new_ip_v4 = next(self._subnet_ip_generator)
+            new_ip_v4 = next(iter(self._subnet_ip_generator))
 
             # Skips any IP's if they've been manually specified
             while str(new_ip_v4) in self._subnet_ips:
-                new_ip_v4 = next(self._subnet_ip_generator)
+                new_ip_v4 = next(iter(self._subnet_ip_generator))
 
             if new_ip_v4 == self.cidr.broadcast_address:
                 raise StopIteration()  # Broadcast address cant be used obviously
@@ -363,42 +366,40 @@ class SubnetBackend:
         ipv6_cidr_block: Optional[str] = None,
         availability_zone: Optional[str] = None,
         availability_zone_id: Optional[str] = None,
+        ipv6_native: bool = False,
         tags: Optional[Dict[str, Dict[str, str]]] = None,
     ) -> Subnet:
         subnet_id = random_subnet_id()
         # Validate VPC exists and the supplied CIDR block is a subnet of the VPC's
         vpc = self.get_vpc(vpc_id)  # type: ignore[attr-defined]
-        vpc_cidr_blocks = [
-            ipaddress.IPv4Network(
-                str(cidr_block_association["cidr_block"]), strict=False
-            )
-            for cidr_block_association in vpc.get_cidr_block_association_set()
-        ]
-        try:
-            subnet_cidr_block = ipaddress.IPv4Network(str(cidr_block), strict=False)
-        except ValueError:
-            raise InvalidCIDRBlockParameterError(cidr_block)
+        if cidr_block:
+            vpc_cidr_blocks = [
+                ipaddress.IPv4Network(
+                    str(cidr_block_association["cidr_block"]), strict=False
+                )
+                for cidr_block_association in vpc.get_cidr_block_association_set()
+            ]
+            try:
+                subnet_cidr_block = ipaddress.IPv4Network(str(cidr_block), strict=False)
+            except ValueError:
+                raise InvalidCIDRBlockParameterError(cidr_block)
 
-        subnet_in_vpc_cidr_range = False
-        for vpc_cidr_block in vpc_cidr_blocks:
-            if (
-                vpc_cidr_block.network_address <= subnet_cidr_block.network_address
-                and vpc_cidr_block.broadcast_address
-                >= subnet_cidr_block.broadcast_address
-            ):
-                subnet_in_vpc_cidr_range = True
-                break
+            subnet_in_vpc_cidr_range = False
+            for vpc_cidr_block in vpc_cidr_blocks:
+                if (
+                    vpc_cidr_block.network_address <= subnet_cidr_block.network_address
+                    and vpc_cidr_block.broadcast_address
+                    >= subnet_cidr_block.broadcast_address
+                ):
+                    subnet_in_vpc_cidr_range = True
+                    break
 
-        if not subnet_in_vpc_cidr_range:
-            raise InvalidSubnetRangeError(cidr_block)
+            if not subnet_in_vpc_cidr_range:
+                raise InvalidSubnetRangeError(cidr_block)
 
-        # The subnet size must use a /64 prefix length.
-        if ipv6_cidr_block and "::/64" not in ipv6_cidr_block:
-            raise GenericInvalidParameterValueError("ipv6-cidr-block", ipv6_cidr_block)
-
-        for subnet in self.describe_subnets(filters={"vpc-id": vpc_id}):
-            if subnet.cidr.overlaps(subnet_cidr_block):
-                raise InvalidSubnetConflictError(cidr_block)
+            for subnet in self.describe_subnets(filters={"vpc-id": vpc_id}):
+                if subnet.cidr.overlaps(subnet_cidr_block):
+                    raise InvalidSubnetConflictError(cidr_block)
 
         # if this is the first subnet for an availability zone,
         # consider it the default
@@ -443,7 +444,7 @@ class SubnetBackend:
             availability_zone_data,
             default_for_az,
             map_public_ip_on_launch,
-            assign_ipv6_address_on_creation=False,
+            ipv6_native=ipv6_native,
         )
 
         for k, v in tags.get("subnet", {}).items() if tags else []:
