@@ -2,17 +2,20 @@ import base64
 import hashlib
 import json
 import os
+import sys
 from unittest import SkipTest, mock
 from uuid import uuid4
 
 import boto3
 import pytest
-from botocore.exceptions import ClientError, ParamValidationError
+from botocore.exceptions import ClientError
 from freezegun import freeze_time
 
-from moto import mock_ecr, mock_lambda, mock_s3, settings
+from moto import mock_aws, settings
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
+from moto.utilities.distutils_version import LooseVersion
 from tests.test_ecr.test_ecr_helpers import _create_image_manifest
+from tests.test_s3 import s3_aws_verified
 
 from . import lambda_aws_verified
 from .utilities import (
@@ -21,29 +24,57 @@ from .utilities import (
     get_role_name,
     get_test_zip_file1,
     get_test_zip_file2,
-    get_test_zip_file3,
 )
 
 PYTHON_VERSION = "python3.11"
 LAMBDA_FUNC_NAME = "test"
 _lambda_region = "us-west-2"
-boto3.setup_default_session(region_name=_lambda_region)
+
+boto3_version = sys.modules["botocore"].__version__
 
 
 @mock.patch.dict("os.environ", {"MOTO_ENABLE_ISO_REGIONS": "true"})
 @pytest.mark.parametrize("region", ["us-west-2", "cn-northwest-1", "us-isob-east-1"])
-@mock_lambda
+@mock_aws
 def test_lambda_regions(region):
     if not settings.TEST_DECORATOR_MODE:
         raise SkipTest("Can only set EnvironVars in DecoratorMode")
+    if LooseVersion(boto3_version) < LooseVersion("1.29.0"):
+        raise SkipTest("ISO-region not available in older versions")
     client = boto3.client("lambda", region_name=region)
     resp = client.list_functions()
     assert resp["ResponseMetadata"]["HTTPStatusCode"] == 200
 
+    function_name = "moto_test_" + str(uuid4())[0:6]
+    function = client.create_function(
+        FunctionName=function_name,
+        Runtime=PYTHON_VERSION,
+        Role=get_role_name(region),
+        Handler="lambda_function.lambda_handler",
+        Code={"ZipFile": get_test_zip_file1()},
+    )
+    if region == "us-west-2":
+        assert (
+            function["FunctionArn"]
+            == f"arn:aws:lambda:{region}:{ACCOUNT_ID}:function:{function_name}"
+        )
+    if region == "cn-northwest-1":
+        assert (
+            function["FunctionArn"]
+            == f"arn:aws-cn:lambda:{region}:{ACCOUNT_ID}:function:{function_name}"
+        )
+    if region == "us-isob-east-1":
+        assert (
+            function["FunctionArn"]
+            == f"arn:aws-iso-b:lambda:{region}:{ACCOUNT_ID}:function:{function_name}"
+        )
+
 
 @pytest.mark.aws_verified
 @lambda_aws_verified
 def test_list_functions(iam_role_arn=None):
+    if LooseVersion(boto3_version) < LooseVersion("1.29.0"):
+        raise SkipTest("Parameters only available in newer versions")
     sts = boto3.client("sts", "eu-west-2")
     account_id = sts.get_caller_identity()["Account"]
 
@@ -71,7 +102,9 @@ def test_list_functions(iam_role_arn=None):
     func_list = conn.list_functions()["Functions"]
     our_functions = [f for f in func_list if f["FunctionName"] == function_name]
     assert len(our_functions) == 1
-    assert our_functions[0]["PackageType"] == "Zip"
+    if LooseVersion(boto3_version) > LooseVersion("1.29.0"):
+        # PackageType only available in new versions
+        assert our_functions[0]["PackageType"] == "Zip"
 
     # FunctionVersion=ALL means we should get a list of all versions
     full_list = conn.list_functions(FunctionVersion="ALL")["Functions"]
@@ -97,7 +130,7 @@ def test_list_functions(iam_role_arn=None):
     conn.delete_function(FunctionName=function_name)
 
 
-@mock_lambda
+@mock_aws
 def test_create_based_on_s3_with_missing_bucket():
     conn = boto3.client("lambda", _lambda_region)
     function_name = str(uuid4())[0:6]
@@ -125,10 +158,11 @@ def test_create_based_on_s3_with_missing_bucket():
     )
 
 
-@mock_lambda
-@mock_s3
+@mock_aws
 @freeze_time("2015-01-01 00:00:00")
 def test_create_function_from_aws_bucket():
+    if LooseVersion(boto3_version) < LooseVersion("1.29.0"):
+        raise SkipTest("Parameters only available in newer versions")
     bucket_name = str(uuid4())
     s3_conn = boto3.client("s3", _lambda_region)
     s3_conn.create_bucket(
@@ -168,9 +202,11 @@ def test_create_function_from_aws_bucket():
     assert result["State"] == "Active"
 
 
-@mock_lambda
+@mock_aws
 @freeze_time("2015-01-01 00:00:00")
 def test_create_function_from_zipfile():
+    if LooseVersion(boto3_version) < LooseVersion("1.29.0"):
+        raise SkipTest("Parameters only available in newer versions")
     conn = boto3.client("lambda", _lambda_region)
     zip_content = get_test_zip_file1()
     function_name = str(uuid4())[0:6]
@@ -189,6 +225,7 @@ def test_create_function_from_zipfile():
     result["ResponseMetadata"].pop("HTTPHeaders", None)
     # Botocore inserts retry attempts not seen in Python27
     result["ResponseMetadata"].pop("RetryAttempts", None)
+    result["ResponseMetadata"].pop("RequestId")
     result.pop("LastModified")
 
     assert result == {
@@ -208,7 +245,6 @@ def test_create_function_from_zipfile():
             "utf-8"
         ),
         "Version": "1",
-        "VpcConfig": {"SecurityGroupIds": [], "SubnetIds": []},
         "ResponseMetadata": {"HTTPStatusCode": 201},
         "State": "Active",
         "Layers": [],
@@ -217,8 +253,10 @@ def test_create_function_from_zipfile():
     }
 
 
-@mock_lambda
+@mock_aws
 def test_create_function_from_image():
+    if LooseVersion(boto3_version) < LooseVersion("1.29.0"):
+        raise SkipTest("Parameters only available in newer versions")
     conn = boto3.client("lambda", _lambda_region)
     function_name = str(uuid4())[0:6]
     image_uri = f"{ACCOUNT_ID}.dkr.ecr.us-east-1.amazonaws.com/testlambdaecr:prod"
@@ -238,9 +276,6 @@ def test_create_function_from_image():
         Description="test lambda function",
         ImageConfig=image_config,
         PackageType="Image",
-        Timeout=3,
-        MemorySize=128,
-        Publish=True,
     )
 
     result = conn.get_function(FunctionName=function_name)
@@ -249,8 +284,10 @@ def test_create_function_from_image():
     assert result["Configuration"]["ImageConfigResponse"]["ImageConfig"] == image_config
 
 
-@mock_lambda
+@mock_aws
 def test_create_function_from_image_default_working_directory():
+    if LooseVersion(boto3_version) < LooseVersion("1.29.0"):
+        raise SkipTest("Parameters only available in newer versions")
     conn = boto3.client("lambda", _lambda_region)
     function_name = str(uuid4())[0:6]
     image_uri = f"{ACCOUNT_ID}.dkr.ecr.us-east-1.amazonaws.com/testlambdaecr:prod"
@@ -269,9 +306,6 @@ def test_create_function_from_image_default_working_directory():
         Description="test lambda function",
         ImageConfig=image_config,
         PackageType="Image",
-        Timeout=3,
-        MemorySize=128,
-        Publish=True,
     )
 
     result = conn.get_function(FunctionName=function_name)
@@ -280,8 +314,10 @@ def test_create_function_from_image_default_working_directory():
     assert result["Configuration"]["ImageConfigResponse"]["ImageConfig"] == image_config
 
 
-@mock_lambda
+@mock_aws
 def test_create_function_error_bad_architecture():
+    if LooseVersion(boto3_version) < LooseVersion("1.29.0"):
+        raise SkipTest("Parameters only available in newer versions")
     conn = boto3.client("lambda", _lambda_region)
     function_name = str(uuid4())[0:6]
     image_uri = f"{ACCOUNT_ID}.dkr.ecr.us-east-1.amazonaws.com/testlambdaecr:prod"
@@ -292,10 +328,6 @@ def test_create_function_error_bad_architecture():
             FunctionName=function_name,
             Role=get_role_name(),
             Code={"ImageUri": image_uri},
-            Description="test lambda function",
-            Timeout=3,
-            MemorySize=128,
-            Publish=True,
         )
 
     err = exc.value.response
@@ -309,8 +341,10 @@ def test_create_function_error_bad_architecture():
     )
 
 
-@mock_lambda
+@mock_aws
 def test_create_function_error_ephemeral_too_big():
+    if LooseVersion(boto3_version) < LooseVersion("1.29.0"):
+        raise SkipTest("Parameters only available in newer versions")
     conn = boto3.client("lambda", _lambda_region)
     function_name = str(uuid4())[0:6]
     image_uri = f"{ACCOUNT_ID}.dkr.ecr.us-east-1.amazonaws.com/testlambdaecr:prod"
@@ -338,29 +372,7 @@ def test_create_function_error_ephemeral_too_big():
     )
 
 
-@mock_lambda
-def test_create_function_error_ephemeral_too_small():
-    conn = boto3.client("lambda", _lambda_region)
-    function_name = str(uuid4())[0:6]
-    image_uri = f"{ACCOUNT_ID}.dkr.ecr.us-east-1.amazonaws.com/testlambdaecr:prod"
-
-    with pytest.raises(ParamValidationError) as exc:
-        conn.create_function(
-            FunctionName=function_name,
-            Role=get_role_name(),
-            Code={"ImageUri": image_uri},
-            Description="test lambda function",
-            Timeout=3,
-            MemorySize=128,
-            Publish=True,
-            EphemeralStorage={"Size": 200},
-        )
-
-    # this one is handled by botocore, not moto
-    assert exc.typename == "ParamValidationError"
-
-
-@mock_lambda
+@mock_aws
 @pytest.mark.parametrize(
     "tracing_mode",
     [(None, "PassThrough"), ("PassThrough", "PassThrough"), ("Active", "Active")],
@@ -389,7 +401,7 @@ def test_create_function__with_tracingmode(tracing_mode):
 
 @pytest.fixture(name="with_ecr_mock")
 def ecr_repo_fixture():
-    with mock_ecr():
+    with mock_aws():
         os.environ["MOTO_LAMBDA_STUB_ECR"] = "FALSE"
         repo_name = "testlambdaecr"
         ecr_client = boto3.client("ecr", "us-east-1")
@@ -404,8 +416,10 @@ def ecr_repo_fixture():
         os.environ["MOTO_LAMBDA_STUB_ECR"] = "TRUE"
 
 
-@mock_lambda
+@mock_aws
 def test_create_function_from_stubbed_ecr():
+    if LooseVersion(boto3_version) < LooseVersion("1.29.0"):
+        raise SkipTest("Parameters only available in newer versions")
     lambda_client = boto3.client("lambda", "us-east-1")
     fn_name = str(uuid4())[0:6]
     image_uri = "111122223333.dkr.ecr.us-east-1.amazonaws.com/testlambda:latest"
@@ -437,10 +451,12 @@ def test_create_function_from_stubbed_ecr():
     assert code["ResolvedImageUri"] == resolved_image_uri
 
 
-@mock_lambda
+@mock_aws
 def test_create_function_from_mocked_ecr_image_tag(
     with_ecr_mock,
-):  # pylint: disable=unused-argument
+):
+    if LooseVersion(boto3_version) < LooseVersion("1.29.0"):
+        raise SkipTest("Parameters only available in newer versions")
     if not settings.TEST_DECORATOR_MODE:
         raise SkipTest(
             "Envars not easily set in server mode, feature off by default, skipping..."
@@ -479,10 +495,12 @@ def test_create_function_from_mocked_ecr_image_tag(
     assert code["ResolvedImageUri"] == resolved_image_uri
 
 
-@mock_lambda
+@mock_aws
 def test_create_function_from_mocked_ecr_image_digest(
     with_ecr_mock,
-):  # pylint: disable=unused-argument
+):
+    if LooseVersion(boto3_version) < LooseVersion("1.29.0"):
+        raise SkipTest("Parameters only available in newer versions")
     if not settings.TEST_DECORATOR_MODE:
         raise SkipTest(
             "Envars not easily set in server mode, feature off by default, skipping..."
@@ -506,10 +524,12 @@ def test_create_function_from_mocked_ecr_image_digest(
     assert resp["PackageType"] == "Image"
 
 
-@mock_lambda
+@mock_aws
 def test_create_function_from_mocked_ecr_missing_image(
     with_ecr_mock,
-):  # pylint: disable=unused-argument
+):
+    if LooseVersion(boto3_version) < LooseVersion("1.29.0"):
+        raise SkipTest("Parameters only available in newer versions")
     if not settings.TEST_DECORATOR_MODE:
         raise SkipTest(
             "Envars not easily set in server mode, feature off by default, skipping..."
@@ -539,26 +559,26 @@ def test_create_function_from_mocked_ecr_missing_image(
     )
 
 
-@mock_lambda
-@mock_s3
-@freeze_time("2015-01-01 00:00:00")
-def test_get_function():
-    bucket_name = str(uuid4())
-    s3_conn = boto3.client("s3", _lambda_region)
-    s3_conn.create_bucket(
-        Bucket=bucket_name,
-        CreateBucketConfiguration={"LocationConstraint": _lambda_region},
-    )
+@pytest.mark.aws_verified
+@lambda_aws_verified
+@s3_aws_verified
+def test_get_function(iam_role_arn=None, bucket_name=None):
+    region = "us-east-1"
+
+    sts = boto3.client("sts", region)
+    account_id = sts.get_caller_identity()["Account"]
+
+    s3_conn = boto3.client("s3", region)
 
     zip_content = get_test_zip_file1()
     s3_conn.put_object(Bucket=bucket_name, Key="test.zip", Body=zip_content)
-    conn = boto3.client("lambda", _lambda_region)
+    conn = boto3.client("lambda", region)
     function_name = str(uuid4())[0:6]
 
     conn.create_function(
         FunctionName=function_name,
         Runtime=PYTHON_VERSION,
-        Role=get_role_name(),
+        Role=iam_role_arn,
         Handler="lambda_function.lambda_handler",
         Code={"S3Bucket": bucket_name, "S3Key": "test.zip"},
         Description="test lambda function",
@@ -569,16 +589,7 @@ def test_get_function():
     )
 
     result = conn.get_function(FunctionName=function_name)
-    # this is hard to match against, so remove it
-    result["ResponseMetadata"].pop("HTTPHeaders", None)
-    # Botocore inserts retry attempts not seen in Python27
-    result["ResponseMetadata"].pop("RetryAttempts", None)
-    result["Configuration"].pop("LastModified")
 
-    assert (
-        result["Code"]["Location"]
-        == f"s3://awslambda-{_lambda_region}-tasks.s3-{_lambda_region}.amazonaws.com/test.zip"
-    )
     assert result["Code"]["RepositoryType"] == "S3"
 
     assert result["Configuration"]["CodeSha256"] == base64.b64encode(
@@ -590,13 +601,11 @@ def test_get_function():
     assert result["Configuration"]["FunctionName"] == function_name
     assert result["Configuration"]["Handler"] == "lambda_function.lambda_handler"
     assert result["Configuration"]["MemorySize"] == 128
-    assert result["Configuration"]["Role"] == get_role_name()
+    assert result["Configuration"]["Role"] == iam_role_arn
     assert result["Configuration"]["Runtime"] == PYTHON_VERSION
     assert result["Configuration"]["Timeout"] == 3
     assert result["Configuration"]["Version"] == "$LATEST"
-    assert "VpcConfig" in result["Configuration"]
-    assert "Environment" in result["Configuration"]
-    assert "Variables" in result["Configuration"]["Environment"]
+    assert "VpcConfig" not in result["Configuration"]
     assert result["Configuration"]["Environment"]["Variables"] == {
         "test_variable": "test_value"
     }
@@ -606,7 +615,7 @@ def test_get_function():
     assert result["Configuration"]["Version"] == "$LATEST"
     assert (
         result["Configuration"]["FunctionArn"]
-        == f"arn:aws:lambda:us-west-2:{ACCOUNT_ID}:function:{function_name}:$LATEST"
+        == f"arn:aws:lambda:{region}:{account_id}:function:{function_name}:$LATEST"
     )
 
     # Test get function with version
@@ -614,7 +623,7 @@ def test_get_function():
     assert result["Configuration"]["Version"] == "1"
     assert (
         result["Configuration"]["FunctionArn"]
-        == f"arn:aws:lambda:us-west-2:{ACCOUNT_ID}:function:{function_name}:1"
+        == f"arn:aws:lambda:{region}:{account_id}:function:{function_name}:1"
     )
 
     # Test get function with version inside of name
@@ -622,17 +631,23 @@ def test_get_function():
     assert result["Configuration"]["Version"] == "1"
     assert (
         result["Configuration"]["FunctionArn"]
-        == f"arn:aws:lambda:us-west-2:{ACCOUNT_ID}:function:{function_name}:1"
+        == f"arn:aws:lambda:{region}:{account_id}:function:{function_name}:1"
     )
 
+    conn.delete_function(FunctionName=function_name)
+
+
+@mock_aws
+def test_get_unknown_function():
+    conn = boto3.client("lambda", _lambda_region)
+
     # Test get function when can't find function name
     with pytest.raises(conn.exceptions.ResourceNotFoundException):
         conn.get_function(FunctionName="junk", Qualifier="$LATEST")
 
 
 @pytest.mark.parametrize("key", ["FunctionName", "FunctionArn"])
-@mock_lambda
-@mock_s3
+@mock_aws
 @freeze_time("2015-01-01 00:00:00")
 def test_get_function_configuration(key):
     bucket_name = str(uuid4())
@@ -676,9 +691,6 @@ def test_get_function_configuration(key):
     assert result["Runtime"] == PYTHON_VERSION
     assert result["Timeout"] == 3
     assert result["Version"] == "$LATEST"
-    assert "VpcConfig" in result
-    assert "Environment" in result
-    assert "Variables" in result["Environment"]
     assert result["Environment"]["Variables"] == {"test_variable": "test_value"}
 
     # Test get function with qualifier
@@ -697,9 +709,10 @@ def test_get_function_configuration(key):
 
 
 @pytest.mark.parametrize("key", ["FunctionName", "FunctionArn"])
-@mock_lambda
-@mock_s3
+@mock_aws
 def test_get_function_code_signing_config(key):
+    if LooseVersion(boto3_version) < LooseVersion("1.29.0"):
+        raise SkipTest("Parameters only available in newer versions")
     bucket_name = str(uuid4())
     s3_conn = boto3.client("s3", _lambda_region)
     s3_conn.create_bucket(
@@ -728,15 +741,11 @@ def test_get_function_code_signing_config(key):
     assert result["CodeSigningConfigArn"] == "csc:arn"
 
 
-@mock_lambda
-@mock_s3
+@mock_aws
 def test_get_function_by_arn():
     bucket_name = str(uuid4())
     s3_conn = boto3.client("s3", "us-east-1")
-    s3_conn.create_bucket(
-        Bucket=bucket_name,
-        CreateBucketConfiguration={"LocationConstraint": _lambda_region},
-    )
+    s3_conn.create_bucket(Bucket=bucket_name)
 
     zip_content = get_test_zip_file2()
     s3_conn.put_object(Bucket=bucket_name, Key="test.zip", Body=zip_content)
@@ -775,8 +784,7 @@ def test_get_function_by_arn():
     )
 
 
-@mock_lambda
-@mock_s3
+@mock_aws
 def test_delete_function():
     bucket_name = str(uuid4())
     s3_conn = boto3.client("s3", _lambda_region)
@@ -807,6 +815,7 @@ def test_delete_function():
     success_result["ResponseMetadata"].pop("HTTPHeaders", None)
     # Botocore inserts retry attempts not seen in Python27
     success_result["ResponseMetadata"].pop("RetryAttempts", None)
+    success_result["ResponseMetadata"].pop("RequestId")
 
     assert success_result == {"ResponseMetadata": {"HTTPStatusCode": 204}}
 
@@ -815,15 +824,11 @@ def test_delete_function():
     assert len(our_functions) == 0
 
 
-@mock_lambda
-@mock_s3
+@mock_aws
 def test_delete_function_by_arn():
     bucket_name = str(uuid4())
     s3_conn = boto3.client("s3", "us-east-1")
-    s3_conn.create_bucket(
-        Bucket=bucket_name,
-        CreateBucketConfiguration={"LocationConstraint": _lambda_region},
-    )
+    s3_conn.create_bucket(Bucket=bucket_name)
 
     zip_content = get_test_zip_file2()
     s3_conn.put_object(Bucket=bucket_name, Key="test.zip", Body=zip_content)
@@ -849,7 +854,7 @@ def test_delete_function_by_arn():
     assert len(our_functions) == 0
 
 
-@mock_lambda
+@mock_aws
 def test_delete_unknown_function():
     conn = boto3.client("lambda", _lambda_region)
     with pytest.raises(ClientError) as exc:
@@ -858,7 +863,7 @@ def test_delete_unknown_function():
     assert err["Code"] == "ResourceNotFoundException"
 
 
-@mock_lambda
+@mock_aws
 @pytest.mark.parametrize(
     "name",
     [
@@ -878,8 +883,7 @@ def test_publish_version_unknown_function(name):
     )
 
 
-@mock_lambda
-@mock_s3
+@mock_aws
 def test_publish():
     bucket_name = str(uuid4())
     s3_conn = boto3.client("s3", _lambda_region)
@@ -929,14 +933,15 @@ def test_publish():
     assert function_name in our_functions[0]["FunctionArn"]
 
 
-@mock_lambda
-@mock_s3
+@mock_aws
 @freeze_time("2015-01-01 00:00:00")
 def test_list_create_list_get_delete_list():
     """
     test `list -> create -> list -> get -> delete -> list` integration
 
     """
+    if LooseVersion(boto3_version) < LooseVersion("1.29.0"):
+        raise SkipTest("Parameters only available in newer versions")
     bucket_name = str(uuid4())
     s3_conn = boto3.client("s3", _lambda_region)
     s3_conn.create_bucket(
@@ -968,7 +973,7 @@ def test_list_create_list_get_delete_list():
     )
     expected_function_result = {
         "Code": {
-            "Location": f"s3://awslambda-{_lambda_region}-tasks.s3-{_lambda_region}.amazonaws.com/test.zip",
+            "Location": f"https://awslambda-{_lambda_region}-tasks.s3.{_lambda_region}.amazonaws.com/test.zip",
             "RepositoryType": "S3",
         },
         "Configuration": {
@@ -985,7 +990,6 @@ def test_list_create_list_get_delete_list():
             "Runtime": PYTHON_VERSION,
             "Timeout": 3,
             "Version": "$LATEST",
-            "VpcConfig": {"SecurityGroupIds": [], "SubnetIds": []},
             "State": "Active",
             "Layers": [],
             "LastUpdateStatus": "Successful",
@@ -1038,6 +1042,7 @@ def test_list_create_list_get_delete_list():
     func["ResponseMetadata"].pop("HTTPHeaders", None)
     # Botocore inserts retry attempts not seen in Python27
     func["ResponseMetadata"].pop("RetryAttempts", None)
+    func["ResponseMetadata"].pop("RequestId")
     func["Configuration"].pop("LastModified")
     func["Configuration"].pop("FunctionArn")
 
@@ -1049,7 +1054,7 @@ def test_list_create_list_get_delete_list():
     assert function_name not in func_names
 
 
-@mock_lambda
+@mock_aws
 @freeze_time("2015-01-01 00:00:00")
 def test_get_function_created_with_zipfile():
     conn = boto3.client("lambda", _lambda_region)
@@ -1062,9 +1067,6 @@ def test_get_function_created_with_zipfile():
         Handler="lambda_function.handler",
         Code={"ZipFile": zip_content},
         Description="test lambda function",
-        Timeout=3,
-        MemorySize=128,
-        Publish=True,
     )
 
     response = conn.get_function(FunctionName=function_name)
@@ -1073,7 +1075,7 @@ def test_get_function_created_with_zipfile():
     assert len(response["Code"]) == 2
     assert response["Code"]["RepositoryType"] == "S3"
     assert response["Code"]["Location"].startswith(
-        f"s3://awslambda-{_lambda_region}-tasks.s3-{_lambda_region}.amazonaws.com"
+        f"https://awslambda-{_lambda_region}-tasks.s3.{_lambda_region}.amazonaws.com"
     )
     assert "Configuration" in response
     config = response["Configuration"]
@@ -1098,8 +1100,7 @@ def test_get_function_created_with_zipfile():
     assert config["LastUpdateStatus"] == "Successful"
 
 
-@mock_lambda
-@mock_s3
+@mock_aws
 def test_list_versions_by_function():
     bucket_name = str(uuid4())
     s3_conn = boto3.client("s3", _lambda_region)
@@ -1162,8 +1163,7 @@ def test_list_versions_by_function():
     )
 
 
-@mock_lambda
-@mock_s3
+@mock_aws
 def test_list_aliases():
     bucket_name = str(uuid4())
     s3_conn = boto3.client("s3", _lambda_region)
@@ -1263,8 +1263,7 @@ def test_list_aliases():
     )
 
 
-@mock_lambda
-@mock_s3
+@mock_aws
 def test_create_function_with_already_exists():
     bucket_name = str(uuid4())
     s3_conn = boto3.client("s3", _lambda_region)
@@ -1306,8 +1305,7 @@ def test_create_function_with_already_exists():
     assert exc.value.response["Error"]["Code"] == "ResourceConflictException"
 
 
-@mock_lambda
-@mock_s3
+@mock_aws
 def test_list_versions_by_function_for_nonexistent_function():
     conn = boto3.client("lambda", _lambda_region)
     function_name = str(uuid4())[0:6]
@@ -1316,26 +1314,23 @@ def test_list_versions_by_function_for_nonexistent_function():
     assert len(versions["Versions"]) == 0
 
 
+@pytest.mark.aws_verified
 @pytest.mark.parametrize("key", ["FunctionName", "FunctionArn"])
-@mock_lambda
-@mock_s3
-def test_update_configuration(key):
-    bucket_name = str(uuid4())
+@lambda_aws_verified
+@s3_aws_verified
+def test_update_configuration(key, bucket_name=None, iam_role_arn=None):
+    region = "us-east-1"
     function_name = str(uuid4())[0:6]
-    s3_conn = boto3.client("s3", _lambda_region)
-    s3_conn.create_bucket(
-        Bucket=bucket_name,
-        CreateBucketConfiguration={"LocationConstraint": _lambda_region},
-    )
+    s3_conn = boto3.client("s3", region)
 
     zip_content = get_test_zip_file2()
     s3_conn.put_object(Bucket=bucket_name, Key="test.zip", Body=zip_content)
-    conn = boto3.client("lambda", _lambda_region)
+    conn = boto3.client("lambda", region)
 
     fxn = conn.create_function(
         FunctionName=function_name,
         Runtime=PYTHON_VERSION,
-        Role=get_role_name(),
+        Role=iam_role_arn,
         Handler="lambda_function.lambda_handler",
         Code={"S3Bucket": bucket_name, "S3Key": "test.zip"},
         Description="test lambda function",
@@ -1346,6 +1341,9 @@ def test_update_configuration(key):
     )
     name_or_arn = fxn[key]
 
+    wait_for_func = conn.get_waiter("function_active")
+    wait_for_func.wait(FunctionName=function_name, WaiterConfig={"Delay": 1})
+
     assert fxn["Description"] == "test lambda function"
     assert fxn["Handler"] == "lambda_function.lambda_handler"
     assert fxn["MemorySize"] == 128
@@ -1356,31 +1354,37 @@ def test_update_configuration(key):
         FunctionName=name_or_arn,
         Description="updated test lambda function",
         Handler="lambda_function.new_lambda_handler",
-        Runtime="python3.6",
+        Runtime="python3.12",
         Timeout=7,
-        VpcConfig={"SecurityGroupIds": ["sg-123abc"], "SubnetIds": ["subnet-123abc"]},
         Environment={"Variables": {"test_environment": "test_value"}},
     )
 
+    wait_for_func = conn.get_waiter("function_updated")
+    wait_for_func.wait(FunctionName=function_name, WaiterConfig={"Delay": 1})
+
     assert updated_config["ResponseMetadata"]["HTTPStatusCode"] == 200
     assert updated_config["Description"] == "updated test lambda function"
     assert updated_config["Handler"] == "lambda_function.new_lambda_handler"
     assert updated_config["MemorySize"] == 128
-    assert updated_config["Runtime"] == "python3.6"
+    assert updated_config["Runtime"] == "python3.12"
     assert updated_config["Timeout"] == 7
     assert updated_config["Environment"]["Variables"] == {
         "test_environment": "test_value"
     }
-    assert updated_config["VpcConfig"] == {
-        "SecurityGroupIds": ["sg-123abc"],
-        "SubnetIds": ["subnet-123abc"],
-        "VpcId": "vpc-123abc",
-    }
+
+    # publish - results in a new version because the config is updated
+    assert conn.publish_version(FunctionName=name_or_arn)["Version"] == "2"
+
+    # publish again - no changes
+    assert conn.publish_version(FunctionName=name_or_arn)["Version"] == "2"
+
+    conn.delete_function(FunctionName=function_name)
 
 
+@pytest.mark.aws_verified
 @pytest.mark.parametrize("key", ["FunctionName", "FunctionArn"])
-@mock_lambda
-def test_update_function_zip(key):
+@lambda_aws_verified
+def test_update_function_zip(key, iam_role_arn=None):
     conn = boto3.client("lambda", _lambda_region)
 
     zip_content_one = get_test_zip_file1()
@@ -1389,7 +1393,7 @@ def test_update_function_zip(key):
     fxn = conn.create_function(
         FunctionName=function_name,
         Runtime=PYTHON_VERSION,
-        Role=get_role_name(),
+        Role=iam_role_arn,
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": zip_content_one},
         Description="test lambda function",
@@ -1398,6 +1402,10 @@ def test_update_function_zip(key):
         Publish=True,
     )
     name_or_arn = fxn[key]
+
+    wait_for_func = conn.get_waiter("function_active")
+    wait_for_func.wait(FunctionName=function_name, WaiterConfig={"Delay": 1})
+
     first_sha = fxn["CodeSha256"]
 
     zip_content_two = get_test_zip_file2()
@@ -1407,53 +1415,64 @@ def test_update_function_zip(key):
     )
     assert update1["CodeSha256"] != first_sha
 
+    wait_for_func = conn.get_waiter("function_updated")
+    wait_for_func.wait(FunctionName=function_name, WaiterConfig={"Delay": 1})
+
     response = conn.get_function(FunctionName=function_name, Qualifier="2")
 
-    assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
-    assert len(response["Code"]) == 2
     assert response["Code"]["RepositoryType"] == "S3"
     assert response["Code"]["Location"].startswith(
-        f"s3://awslambda-{_lambda_region}-tasks.s3-{_lambda_region}.amazonaws.com"
+        f"https://awslambda-{_lambda_region}-tasks.s3.{_lambda_region}.amazonaws.com"
     )
 
     config = response["Configuration"]
     assert config["CodeSize"] == len(zip_content_two)
-    assert config["Description"] == "test lambda function"
-    assert (
-        config["FunctionArn"]
-        == f"arn:aws:lambda:{_lambda_region}:{ACCOUNT_ID}:function:{function_name}:2"
-    )
+    assert config["FunctionArn"].endswith(f"{function_name}:2")
     assert config["FunctionName"] == function_name
     assert config["Version"] == "2"
-    assert config["LastUpdateStatus"] == "Successful"
     assert config["CodeSha256"] == update1["CodeSha256"]
 
     most_recent_config = conn.get_function(FunctionName=function_name)
     assert most_recent_config["Configuration"]["CodeSha256"] == update1["CodeSha256"]
 
-    # Publishing this again, with the same code, gives us the same version
+    # Update the same code, and manually publish
+    conn.update_function_code(FunctionName=name_or_arn, ZipFile=zip_content_two)
+    wait_for_func = conn.get_waiter("function_updated")
+    wait_for_func.wait(FunctionName=function_name, WaiterConfig={"Delay": 1})
+
+    resp = conn.publish_version(FunctionName=name_or_arn)
+    # The code is the same, but the version is still updated
+    assert resp["CodeSha256"] == update1["CodeSha256"]
+    assert resp["Version"] == "3"
+
+    # Calling publish again
+    resp = conn.publish_version(FunctionName=name_or_arn)
+    # Code is the same, as is the version - just because we didn't call 'update_function_code'
+    assert resp["CodeSha256"] == update1["CodeSha256"]
+    assert resp["Version"] == "3"
+
+    # Explicitly publishing this again, with the same code, gives us a new version
     same_update = conn.update_function_code(
         FunctionName=name_or_arn, ZipFile=zip_content_two, Publish=True
     )
-    assert (
-        same_update["FunctionArn"]
-        == most_recent_config["Configuration"]["FunctionArn"] + ":2"
-    )
-    assert same_update["Version"] == "2"
+    assert same_update["FunctionArn"].endswith(f":{function_name}:4")
+    assert same_update["Version"] == "4"
 
-    # Only when updating the code should we have a new version
-    new_update = conn.update_function_code(
-        FunctionName=name_or_arn, ZipFile=get_test_zip_file3(), Publish=True
-    )
-    assert (
-        new_update["FunctionArn"]
-        == most_recent_config["Configuration"]["FunctionArn"] + ":3"
-    )
-    assert new_update["Version"] == "3"
+    wait_for_func = conn.get_waiter("function_updated")
+    wait_for_func.wait(FunctionName=function_name, WaiterConfig={"Delay": 1})
+
+    resp = conn.publish_version(FunctionName=name_or_arn)
+    # The code is the same, so is the version, as the previous update was already published
+    assert resp["CodeSha256"] == update1["CodeSha256"]
+    assert resp["Version"] == "4"
+
+    wait_for_func = conn.get_waiter("function_updated")
+    wait_for_func.wait(FunctionName=function_name, WaiterConfig={"Delay": 1})
+
+    conn.delete_function(FunctionName=function_name)
 
 
-@mock_lambda
-@mock_s3
+@mock_aws
 def test_update_function_s3():
     bucket_name = str(uuid4())
     s3_conn = boto3.client("s3", _lambda_region)
@@ -1496,7 +1515,7 @@ def test_update_function_s3():
     assert len(response["Code"]) == 2
     assert response["Code"]["RepositoryType"] == "S3"
     assert response["Code"]["Location"].startswith(
-        f"s3://awslambda-{_lambda_region}-tasks.s3-{_lambda_region}.amazonaws.com"
+        f"https://awslambda-{_lambda_region}-tasks.s3.{_lambda_region}.amazonaws.com"
     )
 
     config = response["Configuration"]
@@ -1514,8 +1533,10 @@ def test_update_function_s3():
     assert config["LastUpdateStatus"] == "Successful"
 
 
-@mock_lambda
+@mock_aws
 def test_update_function_ecr():
+    if LooseVersion(boto3_version) < LooseVersion("1.29.0"):
+        raise SkipTest("Parameters only available in newer versions")
     conn = boto3.client("lambda", _lambda_region)
     function_name = str(uuid4())[0:6]
     image_uri = f"{ACCOUNT_ID}.dkr.ecr.us-east-1.amazonaws.com/testlambdaecr:prod"
@@ -1570,7 +1591,7 @@ def test_update_function_ecr():
     assert config["LastUpdateStatus"] == "Successful"
 
 
-@mock_lambda
+@mock_aws
 def test_create_function_with_invalid_arn():
     err = create_invalid_lambda("test-iam-role")
     assert (
@@ -1579,7 +1600,7 @@ def test_create_function_with_invalid_arn():
     )
 
 
-@mock_lambda
+@mock_aws
 def test_create_function_with_arn_from_different_account():
     err = create_invalid_lambda("arn:aws:iam::000000000000:role/example_role")
     assert (
@@ -1588,7 +1609,7 @@ def test_create_function_with_arn_from_different_account():
     )
 
 
-@mock_lambda
+@mock_aws
 def test_create_function_with_unknown_arn():
     err = create_invalid_lambda(
         "arn:aws:iam::" + str(ACCOUNT_ID) + ":role/service-role/unknown_role"
@@ -1599,7 +1620,7 @@ def test_create_function_with_unknown_arn():
     )
 
 
-@mock_lambda
+@mock_aws
 def test_remove_unknown_permission_throws_error():
     conn = boto3.client("lambda", _lambda_region)
     zip_content = get_test_zip_file1()
@@ -1620,7 +1641,7 @@ def test_remove_unknown_permission_throws_error():
     assert err["Message"] == "No policy is associated with the given resource."
 
 
-@mock_lambda
+@mock_aws
 def test_multiple_qualifiers():
     client = boto3.client("lambda", "us-east-1")
 
@@ -1668,7 +1689,7 @@ def test_multiple_qualifiers():
     )
 
 
-@mock_lambda
+@mock_aws
 def test_delete_non_existent():
     client = boto3.client("lambda", "us-east-1")
 
@@ -1716,7 +1737,7 @@ def test_get_role_name_utility_race_condition():
     assert len(errors) == 0
 
 
-@mock_lambda
+@mock_aws
 @mock.patch.dict(os.environ, {"MOTO_LAMBDA_CONCURRENCY_QUOTA": "1000"})
 def test_put_function_concurrency_success():
     if not settings.TEST_DECORATOR_MODE:
@@ -1744,7 +1765,7 @@ def test_put_function_concurrency_success():
     assert response["ReservedConcurrentExecutions"] == 900
 
 
-@mock_lambda
+@mock_aws
 @mock.patch.dict(os.environ, {"MOTO_LAMBDA_CONCURRENCY_QUOTA": "don't care"})
 def test_put_function_concurrency_not_enforced():
     del os.environ["MOTO_LAMBDA_CONCURRENCY_QUOTA"]  # i.e. not set by user
@@ -1770,7 +1791,7 @@ def test_put_function_concurrency_not_enforced():
     assert response["ReservedConcurrentExecutions"] == 901
 
 
-@mock_lambda
+@mock_aws
 @mock.patch.dict(os.environ, {"MOTO_LAMBDA_CONCURRENCY_QUOTA": "1000"})
 def test_put_function_concurrency_failure():
     if not settings.TEST_DECORATOR_MODE:
@@ -1804,7 +1825,7 @@ def test_put_function_concurrency_failure():
     assert "ReservedConcurrentExecutions" not in response
 
 
-@mock_lambda
+@mock_aws
 @mock.patch.dict(os.environ, {"MOTO_LAMBDA_CONCURRENCY_QUOTA": "1000"})
 def test_put_function_concurrency_i_can_has_math():
     if not settings.TEST_DECORATOR_MODE:
@@ -1864,7 +1885,7 @@ def test_put_function_concurrency_i_can_has_math():
     assert response["ReservedConcurrentExecutions"] == 100
 
 
-@mock_lambda
+@mock_aws
 @pytest.mark.parametrize(
     "config",
     [
@@ -1912,7 +1933,7 @@ def test_put_event_invoke_config(config):
     client.delete_function(FunctionName=arn_2)
 
 
-@mock_lambda
+@mock_aws
 @pytest.mark.parametrize(
     "config",
     [
@@ -1960,7 +1981,7 @@ def test_update_event_invoke_config(config):
     client.delete_function(FunctionName=arn_2)
 
 
-@mock_lambda
+@mock_aws
 def test_put_event_invoke_config_errors_1():
     # Setup
     client = boto3.client("lambda", _lambda_region)
@@ -1990,7 +2011,7 @@ def test_put_event_invoke_config_errors_1():
     client.delete_function(FunctionName=arn_1)
 
 
-@mock_lambda
+@mock_aws
 def test_put_event_invoke_config_errors_2():
     # Setup
     client = boto3.client("lambda", _lambda_region)
@@ -2022,7 +2043,7 @@ def test_put_event_invoke_config_errors_2():
     client.delete_function(FunctionName=arn_2)
 
 
-@mock_lambda
+@mock_aws
 def test_put_event_invoke_config_errors_3():
     # Setup
     client = boto3.client("lambda", _lambda_region)
@@ -2048,7 +2069,7 @@ def test_put_event_invoke_config_errors_3():
     client.delete_function(FunctionName=arn_1)
 
 
-@mock_lambda
+@mock_aws
 def test_put_event_invoke_config_errors_4():
     # Setup
     client = boto3.client("lambda", _lambda_region)
@@ -2074,7 +2095,7 @@ def test_put_event_invoke_config_errors_4():
     client.delete_function(FunctionName=arn_1)
 
 
-@mock_lambda
+@mock_aws
 def test_get_event_invoke_config():
     # Setup
     client = boto3.client("lambda", _lambda_region)
@@ -2101,7 +2122,7 @@ def test_get_event_invoke_config():
     client.delete_function(FunctionName=arn_2)
 
 
-@mock_lambda
+@mock_aws
 def test_list_event_invoke_configs():
     # Setup
     client = boto3.client("lambda", _lambda_region)
@@ -2134,7 +2155,7 @@ def test_list_event_invoke_configs():
     client.delete_function(FunctionName=arn_2)
 
 
-@mock_lambda
+@mock_aws
 def test_get_event_invoke_config_empty():
     # Setup
     client = boto3.client("lambda", _lambda_region)
@@ -2157,7 +2178,7 @@ def test_get_event_invoke_config_empty():
     client.delete_function(FunctionName=arn_1)
 
 
-@mock_lambda
+@mock_aws
 def test_delete_event_invoke_config():
     # Setup
     client = boto3.client("lambda", _lambda_region)
