@@ -1,12 +1,16 @@
+import datetime
+
 import pytest
 from freezegun import freeze_time
 
 from moto.core.utils import (
+    camelcase_to_pascal,
     camelcase_to_underscores,
+    pascal_to_camelcase,
+    rfc_1123_datetime,
+    str_to_rfc_1123_datetime,
     underscores_to_camelcase,
     unix_time,
-    camelcase_to_pascal,
-    pascal_to_camelcase,
 )
 
 
@@ -19,7 +23,7 @@ from moto.core.utils import (
         ("ListMFADevices", "list_mfa_devices"),
     ],
 )
-def test_camelcase_to_underscores(_input, expected):
+def test_camelcase_to_underscores(_input: str, expected: str) -> None:
     assert camelcase_to_underscores(_input) == expected
 
 
@@ -27,7 +31,7 @@ def test_camelcase_to_underscores(_input, expected):
     "_input,expected",
     [("the_new_attribute", "theNewAttribute"), ("attribute", "attribute")],
 )
-def test_underscores_to_camelcase(_input, expected):
+def test_underscores_to_camelcase(_input: str, expected: str) -> None:
     assert underscores_to_camelcase(_input) == expected
 
 
@@ -35,7 +39,7 @@ def test_underscores_to_camelcase(_input, expected):
     "_input,expected",
     [("TheNewAttribute", "theNewAttribute"), ("Attribute", "attribute")],
 )
-def test_pascal_to_camelcase(_input, expected):
+def test_pascal_to_camelcase(_input: str, expected: str) -> None:
     assert pascal_to_camelcase(_input) == expected
 
 
@@ -43,10 +47,17 @@ def test_pascal_to_camelcase(_input, expected):
     "_input,expected",
     [("theNewAttribute", "TheNewAttribute"), ("attribute", "Attribute")],
 )
-def test_camelcase_to_pascal(_input, expected):
+def test_camelcase_to_pascal(_input: str, expected: str) -> None:
     assert camelcase_to_pascal(_input) == expected
 
 
 @freeze_time("2015-01-01 12:00:00")
-def test_unix_time():
+def test_unix_time() -> None:  # type: ignore[misc]
     assert unix_time() == 1420113600.0
+
+
+def test_rfc1123_dates() -> None:
+    with freeze_time("2012-03-04 05:00:05"):
+        x = rfc_1123_datetime(datetime.datetime.now())
+        assert x == "Sun, 04 Mar 2012 05:00:05 GMT"
+        assert str_to_rfc_1123_datetime(x) == datetime.datetime.now()
