@@ -1,4 +1,5 @@
 import pytest
+
 from moto.dynamodb.exceptions import DynamodbException
 from moto.dynamodb.parsing.key_condition_expression import parse_expression
 
@@ -9,15 +10,15 @@ class TestHashKey:
     @pytest.mark.parametrize("expression", ["job_id = :id", "job_id = :id "])
     def test_hash_key_only(self, expression):
         eav = {":id": {"S": "asdasdasd"}}
-        desired_hash_key, comparison, range_values = parse_expression(
+        desired_hash_key, comparison, range_values, _ = parse_expression(
             expression_attribute_values=eav,
             key_condition_expression=expression,
             schema=self.schema,
             expression_attribute_names=dict(),
         )
-        desired_hash_key.should.equal(eav[":id"])
-        comparison.should.equal(None)
-        range_values.should.equal([])
+        assert desired_hash_key == eav[":id"]
+        assert comparison is None
+        assert range_values == []
 
     def test_unknown_hash_key(self):
         kce = "wrongName = :id"
@@ -29,24 +30,7 @@ class TestHashKey:
                 schema=self.schema,
                 expression_attribute_names=dict(),
             )
-        exc.value.message.should.equal(
-            "Query condition missed key schema element: job_id"
-        )
-
-    def test_unknown_hash_value(self):
-        # TODO: is this correct? I'd assume that this should throw an error instead
-        # Revisit after test in exceptions.py passes
-        kce = "job_id = :unknown"
-        eav = {":id": {"S": "asdasdasd"}}
-        desired_hash_key, comparison, range_values = parse_expression(
-            expression_attribute_values=eav,
-            key_condition_expression=kce,
-            schema=self.schema,
-            expression_attribute_names=dict(),
-        )
-        desired_hash_key.should.equal({"S": ":unknown"})
-        comparison.should.equal(None)
-        range_values.should.equal([])
+        assert exc.value.message == "Query condition missed key schema element: job_id"
 
 
 class TestHashAndRangeKey:
@@ -65,9 +49,7 @@ class TestHashAndRangeKey:
                 schema=self.schema,
                 expression_attribute_names=dict(),
             )
-        exc.value.message.should.equal(
-            "Query condition missed key schema element: job_id"
-        )
+        assert exc.value.message == "Query condition missed key schema element: job_id"
 
     @pytest.mark.parametrize(
         "expr",
@@ -86,8 +68,8 @@ class TestHashAndRangeKey:
                 schema=self.schema,
                 expression_attribute_names=dict(),
             )
-        exc.value.message.should.equal(
-            "Query condition missed key schema element: start_date"
+        assert (
+            exc.value.message == "Query condition missed key schema element: start_date"
         )
 
     @pytest.mark.parametrize(
@@ -102,15 +84,15 @@ class TestHashAndRangeKey:
     )
     def test_begin_with(self, expr):
         eav = {":id": "pk", ":sk": "19"}
-        desired_hash_key, comparison, range_values = parse_expression(
+        desired_hash_key, comparison, range_values, _ = parse_expression(
             expression_attribute_values=eav,
             key_condition_expression=expr,
             schema=self.schema,
             expression_attribute_names=dict(),
         )
-        desired_hash_key.should.equal("pk")
-        comparison.should.equal("BEGINS_WITH")
-        range_values.should.equal(["19"])
+        assert desired_hash_key == "pk"
+        assert comparison == "BEGINS_WITH"
+        assert range_values == ["19"]
 
     @pytest.mark.parametrize("fn", ["Begins_with", "Begins_With", "BEGINS_WITH"])
     def test_begin_with__wrong_case(self, fn):
@@ -122,8 +104,9 @@ class TestHashAndRangeKey:
                 schema=self.schema,
                 expression_attribute_names=dict(),
             )
-        exc.value.message.should.equal(
-            f"Invalid KeyConditionExpression: Invalid function name; function: {fn}"
+        assert (
+            exc.value.message
+            == f"Invalid KeyConditionExpression: Invalid function name; function: {fn}"
         )
 
     @pytest.mark.parametrize(
@@ -136,29 +119,29 @@ class TestHashAndRangeKey:
     )
     def test_in_between(self, expr):
         eav = {":id": "pk", ":sk1": "19", ":sk2": "21"}
-        desired_hash_key, comparison, range_values = parse_expression(
+        desired_hash_key, comparison, range_values, _ = parse_expression(
             expression_attribute_values=eav,
             key_condition_expression=expr,
             schema=self.schema,
             expression_attribute_names=dict(),
         )
-        desired_hash_key.should.equal("pk")
-        comparison.should.equal("BETWEEN")
-        range_values.should.equal(["19", "21"])
+        assert desired_hash_key == "pk"
+        assert comparison == "BETWEEN"
+        assert range_values == ["19", "21"]
 
     @pytest.mark.parametrize("operator", [" < ", " <=", "= ", ">", ">="])
     def test_numeric_comparisons(self, operator):
         eav = {":id": "pk", ":sk": "19"}
         expr = f"job_id = :id and start_date{operator}:sk"
-        desired_hash_key, comparison, range_values = parse_expression(
+        desired_hash_key, comparison, range_values, _ = parse_expression(
             expression_attribute_values=eav,
             key_condition_expression=expr,
             schema=self.schema,
             expression_attribute_names=dict(),
         )
-        desired_hash_key.should.equal("pk")
-        comparison.should.equal(operator.strip())
-        range_values.should.equal(["19"])
+        assert desired_hash_key == "pk"
+        assert comparison == operator.strip()
+        assert range_values == ["19"]
 
     @pytest.mark.parametrize(
         "expr",
@@ -171,13 +154,30 @@ class TestHashAndRangeKey:
     )
     def test_reverse_keys(self, expr):
         eav = {":id": "pk", ":sk1": "19", ":sk2": "21"}
-        desired_hash_key, comparison, range_values = parse_expression(
+        desired_hash_key, comparison, range_values, _ = parse_expression(
             expression_attribute_values=eav,
             key_condition_expression=expr,
             schema=self.schema,
             expression_attribute_names=dict(),
         )
-        desired_hash_key.should.equal("pk")
+        assert desired_hash_key == "pk"
+
+    @pytest.mark.parametrize(
+        "expr",
+        [
+            "(job_id = :id) and start_date = :sk",
+            "job_id = :id and (start_date = :sk)",
+            "(job_id = :id) and (start_date = :sk)",
+        ],
+    )
+    def test_brackets(self, expr):
+        desired_hash_key, comparison, range_values, _ = parse_expression(
+            expression_attribute_values={":id": "pk", ":sk": "19"},
+            key_condition_expression=expr,
+            schema=self.schema,
+            expression_attribute_names=dict(),
+        )
+        assert desired_hash_key == "pk"
 
 
 class TestNamesAndValues:
@@ -187,12 +187,27 @@ class TestNamesAndValues:
         kce = ":j = :id"
         ean = {":j": "job_id"}
         eav = {":id": {"S": "asdasdasd"}}
-        desired_hash_key, comparison, range_values = parse_expression(
+        desired_hash_key, comparison, range_values, _ = parse_expression(
             expression_attribute_values=eav,
             key_condition_expression=kce,
             schema=self.schema,
             expression_attribute_names=ean,
         )
-        desired_hash_key.should.equal(eav[":id"])
-        comparison.should.equal(None)
-        range_values.should.equal([])
+        assert desired_hash_key == eav[":id"]
+        assert comparison is None
+        assert range_values == []
+
+
+def test_expression_attribute_names_found():
+    kce = ":j = :id"
+    ean = {":j": "job_id"}
+    eav = {":id": {"S": "asdasdasd"}}
+    desired_hash_key, comparison, range_values, expression_attribute_names_used = (
+        parse_expression(
+            expression_attribute_values=eav,
+            key_condition_expression=kce,
+            schema=[{"AttributeName": "job_id", "KeyType": "HASH"}],
+            expression_attribute_names=ean,
+        )
+    )
+    assert expression_attribute_names_used == [":j"]
