@@ -3,10 +3,16 @@ from unittest import SkipTest
 
 import boto3
 import pytest
+from botocore.exceptions import ClientError
 
 from moto import mock_aws, settings
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
-from tests.test_ec2 import ec2_aws_verified
+from tests.test_ec2 import (
+    delete_tg_attachments,
+    ec2_aws_verified,
+    wait_for_transit_gateway_attachments,
+    wait_for_vpn_connections,
+)
 
 
 @mock_aws
@@ -212,31 +218,44 @@ def retrieve_all_transit_gateways(ec2):
     return all_tg
 
 
-@mock_aws
-def test_create_transit_gateway_vpn_attachment():
-    ec2 = boto3.client("ec2", region_name="us-west-1")
+@pytest.mark.aws_verified
+@ec2_aws_verified(create_transit_gateway=True, create_customer_gateway=True)
+def test_create_transit_gateway_vpn_attachment(ec2_client=None, tg_id=None, cg_id=None):
+    vpn_conn_id = None
+    try:
+        vpn_connection = ec2_client.create_vpn_connection(
+            Type="ipsec.1",
+            CustomerGatewayId=cg_id,
+            TransitGatewayId=tg_id,
+        )["VpnConnection"]
+        vpn_conn_id = vpn_connection["VpnConnectionId"]
+        wait_for_vpn_connections(ec2_client, vpn_connection_id=vpn_conn_id)
 
-    vpn_gateway = ec2.create_vpn_gateway(Type="ipsec.1").get("VpnGateway", {})
-    customer_gateway = ec2.create_customer_gateway(
-        Type="ipsec.1", PublicIp="205.251.242.54", BgpAsn=65534
-    ).get("CustomerGateway", {})
-    vpn_connection = ec2.create_vpn_connection(
-        Type="ipsec.1",
-        VpnGatewayId=vpn_gateway["VpnGatewayId"],
-        CustomerGatewayId=customer_gateway["CustomerGatewayId"],
-        TransitGatewayId="gateway_id",
-    )["VpnConnection"]
-    vpn_conn_id = vpn_connection["VpnConnectionId"]
+        # Get default RouteTableID
+        default_route_table_id = ec2_client.describe_transit_gateway_route_tables(
+            Filters=[{"Name": "transit-gateway-id", "Values": [tg_id]}]
+        )["TransitGatewayRouteTables"][0]["TransitGatewayRouteTableId"]
 
-    #
-    # Verify we can retrieve it as a general attachment
-    attachments = retrieve_all_attachments(ec2)
-    assert vpn_conn_id in [a["ResourceId"] for a in attachments]
+        #
+        # Verify we can retrieve it as a general attachment
+        attachments = retrieve_all_attachments(ec2_client)
+        assert vpn_conn_id in [a["ResourceId"] for a in attachments]
 
-    my_attachments = [a for a in attachments if a["ResourceId"] == vpn_conn_id]
-    assert len(my_attachments) == 1
+        my_attachments = [a for a in attachments if a["ResourceId"] == vpn_conn_id]
 
-    assert my_attachments[0]["ResourceType"] == "vpn"
+        assert len(my_attachments) == 1
+        attachment = my_attachments[0]
+
+        assert attachment["Association"] == {
+            "State": "associated",
+            "TransitGatewayRouteTableId": default_route_table_id,
+        }
+        assert attachment["ResourceType"] == "vpn"
+        assert attachment["ResourceId"] == vpn_conn_id
+        assert attachment["TransitGatewayId"] == tg_id
+    finally:
+        if vpn_conn_id:
+            ec2_client.delete_vpn_connection(VpnConnectionId=vpn_conn_id)
 
 
 def retrieve_all_attachments(client):
@@ -261,6 +280,12 @@ def test_create_and_describe_transit_gateway_vpc_attachment(
         SubnetIds=[subnet_id],
     )
     create = response["TransitGatewayVpcAttachment"]
+    tg_attachment_id = create["TransitGatewayAttachmentId"]
+
+    # Get default RouteTableID
+    default_route_table_id = ec2_client.describe_transit_gateway_route_tables(
+        Filters=[{"Name": "transit-gateway-id", "Values": [tg_id]}]
+    )["TransitGatewayRouteTables"][0]["TransitGatewayRouteTableId"]
 
     assert create["TransitGatewayAttachmentId"].startswith("tgw-attach-")
     assert create["TransitGatewayId"] == tg_id
@@ -276,20 +301,21 @@ def test_create_and_describe_transit_gateway_vpc_attachment(
     assert create["Options"]["SecurityGroupReferencingSupport"] in ["disable", "enable"]
     assert "Tags" not in create
     assert "CreationTime" in create
+
+    # Wait until the attachment is fully ready
+    wait_for_transit_gateway_attachments(ec2_client, tg_attachment_id=tg_attachment_id)
+
     #
     # Verify we can retrieve it as a VPC attachment
     attachments = ec2_client.describe_transit_gateway_vpc_attachments(
-        TransitGatewayAttachmentIds=[create["TransitGatewayAttachmentId"]]
+        TransitGatewayAttachmentIds=[tg_attachment_id]
     )["TransitGatewayVpcAttachments"]
     assert len(attachments) == 1
     describe = attachments[0]
     assert "CreationTime" in describe
     assert describe["Options"] == create["Options"]
-    # AWS returns 'pending' - Moto is immediately 'available'
-    assert describe["State"] in ["pending", "available"]
-    assert (
-        describe["TransitGatewayAttachmentId"] == create["TransitGatewayAttachmentId"]
-    )
+    assert describe["State"] == "available"
+    assert describe["TransitGatewayAttachmentId"] == tg_attachment_id
     assert describe["TransitGatewayId"] == tg_id
     assert describe["VpcId"] == vpc_id
     assert describe["VpcOwnerId"] == account_id
@@ -297,7 +323,7 @@ def test_create_and_describe_transit_gateway_vpc_attachment(
     #
     # Verify we can retrieve it as a general attachment
     attachments = ec2_client.describe_transit_gateway_attachments(
-        TransitGatewayAttachmentIds=[describe["TransitGatewayAttachmentId"]]
+        TransitGatewayAttachmentIds=[tg_attachment_id]
     )["TransitGatewayAttachments"]
     assert len(attachments) == 1
     assert "CreationTime" in attachments[0]
@@ -305,13 +331,13 @@ def test_create_and_describe_transit_gateway_vpc_attachment(
     assert attachments[0]["ResourceOwnerId"] == account_id
     assert attachments[0]["ResourceType"] == "vpc"
     assert attachments[0]["ResourceId"] == vpc_id
-    # AWS returns 'pending' - Moto is immediately 'available'
-    assert attachments[0]["State"] in ["pending", "available"]
-    assert (
-        attachments[0]["TransitGatewayAttachmentId"]
-        == describe["TransitGatewayAttachmentId"]
-    )
+    assert attachments[0]["State"] == "available"
+    assert attachments[0]["TransitGatewayAttachmentId"] == tg_attachment_id
     assert attachments[0]["TransitGatewayId"] == tg_id
+    assert attachments[0]["Association"] == {
+        "TransitGatewayRouteTableId": default_route_table_id,
+        "State": "associated",
+    }
 
 
 @mock_aws
@@ -686,7 +712,7 @@ def test_delete_transit_gateway_vpc_attachment():
         TransitGatewayId=gateway_id, VpcId="vpc-id", SubnetIds=["sub1"]
     )["TransitGatewayVpcAttachment"]["TransitGatewayAttachmentId"]
     a2 = ec2.create_transit_gateway_vpc_attachment(
-        TransitGatewayId=gateway_id, VpcId="vpc-id", SubnetIds=["sub1"]
+        TransitGatewayId=gateway_id, VpcId="vpc-id2", SubnetIds=["sub1"]
     )["TransitGatewayVpcAttachment"]["TransitGatewayAttachmentId"]
 
     available = ec2.describe_transit_gateway_vpc_attachments(
@@ -708,7 +734,157 @@ def test_delete_transit_gateway_vpc_attachment():
     assert [a["TransitGatewayAttachmentId"] for a in all_attchmnts] == [a2]
 
 
+@pytest.mark.aws_verified
+@ec2_aws_verified(create_vpc=False, create_subnet=False, create_transit_gateway=True)
+def test_default_route_table(account_id, ec2_client=None, tg_id=None):
+    existing_tables = ec2_client.describe_transit_gateway_route_tables(
+        Filters=[{"Name": "transit-gateway-id", "Values": [tg_id]}]
+    )["TransitGatewayRouteTables"]
+    assert len(existing_tables) == 1
+    assert existing_tables[0]["TransitGatewayId"] == tg_id
+    assert existing_tables[0]["DefaultAssociationRouteTable"] is True
+    assert existing_tables[0]["DefaultPropagationRouteTable"] is True
+
+    initial = ec2_client.get_transit_gateway_route_table_associations(
+        TransitGatewayRouteTableId=existing_tables[0]["TransitGatewayRouteTableId"]
+    )
+    assert initial["Associations"] == []
+
+
+@pytest.mark.aws_verified
+@ec2_aws_verified(create_vpc=True, create_subnet=True, create_transit_gateway=True)
+def test_new_attachment_is_immediately_associated_to_default_route_table(
+    account_id, ec2_client=None, vpc_id=None, subnet_id=None, tg_id=None
+):
+    # Get default RouteTableID
+    default_route_table_id = ec2_client.describe_transit_gateway_route_tables(
+        Filters=[{"Name": "transit-gateway-id", "Values": [tg_id]}]
+    )["TransitGatewayRouteTables"][0]["TransitGatewayRouteTableId"]
+
+    # Create VPC Attachment
+    attchmnt = ec2_client.create_transit_gateway_vpc_attachment(
+        TransitGatewayId=tg_id, VpcId=vpc_id, SubnetIds=[subnet_id]
+    )["TransitGatewayVpcAttachment"]
+    tg_attachment_id = attchmnt["TransitGatewayAttachmentId"]
+    wait_for_transit_gateway_attachments(ec2_client, tg_attachment_id=tg_attachment_id)
+
+    # Verify Attachment is associated to default RouteTable
+    assocs = ec2_client.get_transit_gateway_route_table_associations(
+        TransitGatewayRouteTableId=default_route_table_id
+    )["Associations"]
+    assert len(assocs) == 1
+    assert assocs[0] == {
+        "TransitGatewayAttachmentId": tg_attachment_id,
+        "ResourceId": vpc_id,
+        "ResourceType": "vpc",
+        "State": "associated",
+    }
+
+
+@pytest.mark.aws_verified
+@ec2_aws_verified(create_vpc=True, create_subnet=True)
+def test_create_vpc_attachment_to_unknown_transit_gateway(
+    account_id, ec2_client=None, vpc_id=None, subnet_id=None
+):
+    # Create VPC Attachment to unknown TransitGateway
+    with pytest.raises(ClientError) as exc:
+        ec2_client.create_transit_gateway_vpc_attachment(
+            TransitGatewayId="tgw-fb63e95d22999bf27",
+            VpcId=vpc_id,
+            SubnetIds=[subnet_id],
+        )
+    err = exc.value.response["Error"]
+    assert err["Code"] == "InvalidTransitGatewayID.NotFound"
+    assert (
+        err["Message"]
+        == "Transit Gateway tgw-fb63e95d22999bf27 was deleted or does not exist."
+    )
+
+
+@pytest.mark.aws_verified
+@ec2_aws_verified(create_vpc=True, create_subnet=True, create_transit_gateway=True)
+def test_create_vpc_attachment_twice(
+    account_id, ec2_client=None, vpc_id=None, subnet_id=None, tg_id=None
+):
+    # Create VPC Attachment one
+    attchmnt1 = ec2_client.create_transit_gateway_vpc_attachment(
+        TransitGatewayId=tg_id, VpcId=vpc_id, SubnetIds=[subnet_id]
+    )["TransitGatewayVpcAttachment"]
+    tg_attachment_id1 = attchmnt1["TransitGatewayAttachmentId"]
+    wait_for_transit_gateway_attachments(ec2_client, tg_attachment_id=tg_attachment_id1)
+
+    # Create VPC Attachment two
+    with pytest.raises(ClientError) as exc:
+        ec2_client.create_transit_gateway_vpc_attachment(
+            TransitGatewayId=tg_id, VpcId=vpc_id, SubnetIds=[subnet_id]
+        )
+    err = exc.value.response["Error"]
+    assert err["Code"] == "DuplicateTransitGatewayAttachment"
+    assert (
+        err["Message"]
+        == f"{tg_id} has non-deleted Transit Gateway Attachments with same VPC ID."
+    )
+
+
+@pytest.mark.aws_verified
+@ec2_aws_verified(create_vpc=True, create_subnet=True, create_transit_gateway=True)
+def test_create_vpc_attachment_for_different_vpcs(
+    account_id, ec2_client=None, vpc_id=None, subnet_id=None, tg_id=None
+):
+    vpc_id1 = vpc_id
+    # Get default RouteTableID
+    default_route_table_id = ec2_client.describe_transit_gateway_route_tables(
+        Filters=[{"Name": "transit-gateway-id", "Values": [tg_id]}]
+    )["TransitGatewayRouteTables"][0]["TransitGatewayRouteTableId"]
+
+    # Create VPC Attachment one
+    attchmnt1 = ec2_client.create_transit_gateway_vpc_attachment(
+        TransitGatewayId=tg_id, VpcId=vpc_id, SubnetIds=[subnet_id]
+    )["TransitGatewayVpcAttachment"]
+    tg_attachment_id1 = attchmnt1["TransitGatewayAttachmentId"]
+    wait_for_transit_gateway_attachments(ec2_client, tg_attachment_id=tg_attachment_id1)
+
+    def _create_second_attachment(ec2_client=None, vpc_id=None, subnet_id=None):
+        vpc_id2 = vpc_id
+        try:
+            # Create VPC Attachment one
+            attchmnt2 = ec2_client.create_transit_gateway_vpc_attachment(
+                TransitGatewayId=tg_id, VpcId=vpc_id, SubnetIds=[subnet_id]
+            )["TransitGatewayVpcAttachment"]
+            tg_attachment_id2 = attchmnt2["TransitGatewayAttachmentId"]
+            wait_for_transit_gateway_attachments(
+                ec2_client, tg_attachment_id=tg_attachment_id2
+            )
+
+            assocs = ec2_client.get_transit_gateway_route_table_associations(
+                TransitGatewayRouteTableId=default_route_table_id
+            )["Associations"]
+            assert len(assocs) == 2
+            assert {
+                "TransitGatewayAttachmentId": tg_attachment_id1,
+                "ResourceId": vpc_id1,
+                "ResourceType": "vpc",
+                "State": "associated",
+            } in assocs
+            assert {
+                "TransitGatewayAttachmentId": tg_attachment_id2,
+                "ResourceId": vpc_id2,
+                "ResourceType": "vpc",
+                "State": "associated",
+            } in assocs
+        finally:
+            # The Attachment is deleted automatically, but only outside the scope of this function
+            # Deleting the VPC inside this function is therefore impossible
+            # That's why we delete the Attachment here manually
+            delete_tg_attachments(ec2_client, tg_id=tg_id)
+
+    # Create the second attachment inside the `ec2_aws_verified` function
+    # This will automatically create (and destroy!) the VPC/subnet resources that we need
+    ec2_aws_verified(create_vpc=True, create_subnet=True)(_create_second_attachment)()
+
+
 @mock_aws
+# TODO: run this against AWS, and check for Assocation-key
 def test_associate_transit_gateway_route_table():
     ec2 = boto3.client("ec2", region_name="us-west-1")
     gateway_id = ec2.create_transit_gateway(Description="g")["TransitGateway"][
@@ -721,18 +897,6 @@ def test_associate_transit_gateway_route_table():
         "TransitGatewayRouteTable"
     ]
 
-    initial = ec2.get_transit_gateway_route_table_associations(
-        TransitGatewayRouteTableId=table["TransitGatewayRouteTableId"]
-    )
-    assert initial["Associations"] == [
-        {
-            "TransitGatewayAttachmentId": "",
-            "ResourceId": "",
-            "ResourceType": "",
-            "State": "",
-        }
-    ]
-
     ec2.associate_transit_gateway_route_table(
         TransitGatewayAttachmentId=attchmnt["TransitGatewayAttachmentId"],
         TransitGatewayRouteTableId=table["TransitGatewayRouteTableId"],
@@ -764,11 +928,6 @@ def test_disassociate_transit_gateway_route_table():
         "TransitGatewayRouteTable"
     ]
 
-    initial = ec2.get_transit_gateway_route_table_associations(
-        TransitGatewayRouteTableId=table["TransitGatewayRouteTableId"]
-    )["Associations"][0]
-    assert initial["TransitGatewayAttachmentId"] == ""
-
     ec2.associate_transit_gateway_route_table(
         TransitGatewayAttachmentId=attchmnt["TransitGatewayAttachmentId"],
         TransitGatewayRouteTableId=table["TransitGatewayRouteTableId"],
@@ -790,9 +949,8 @@ def test_disassociate_transit_gateway_route_table():
 
     updated = ec2.get_transit_gateway_route_table_associations(
         TransitGatewayRouteTableId=table["TransitGatewayRouteTableId"]
-    )["Associations"][0]
-    assert updated["TransitGatewayAttachmentId"] == ""
-    assert updated["State"] == ""
+    )["Associations"]
+    assert len(updated) == 0
 
 
 @mock_aws
