@@ -1,9 +1,11 @@
 """Unit tests for es-supported APIs."""
+
 import boto3
 import pytest
 from botocore.exceptions import ClientError
 
-from moto import mock_es
+from moto import mock_aws
+from tests import DEFAULT_ACCOUNT_ID
 
 # See our Development Tips on writing tests for hints on how to write good tests:
 # http://docs.getmoto.org/en/latest/docs/contributing/development_tips/tests.html
@@ -12,7 +14,7 @@ from moto import mock_es
 @pytest.mark.parametrize(
     "name", ["getmoto.org", "search-is-$$$", "dev_or_test", "dev/test", "1love", "DEV"]
 )
-@mock_es
+@mock_aws
 def test_create_domain_invalid_name(name):
     client = boto3.client("es", region_name="us-east-2")
     with pytest.raises(ClientError) as exc:
@@ -25,14 +27,17 @@ def test_create_domain_invalid_name(name):
     assert err["Code"] == "ValidationException"
 
 
-@mock_es
+@mock_aws
 def test_create_elasticsearch_domain_minimal():
     client = boto3.client("es", region_name="us-east-2")
     resp = client.create_elasticsearch_domain(DomainName="motosearch")
 
     domain = resp["DomainStatus"]
     assert domain["DomainName"] == "motosearch"
-    assert domain["ARN"] == f"arn:aws:es:us-east-2:domain/{domain['DomainId']}"
+    assert (
+        domain["ARN"]
+        == f"arn:aws:es:us-east-2:{DEFAULT_ACCOUNT_ID}:domain/{domain['DomainName']}"
+    )
     assert domain["Created"] is True
     assert domain["Deleted"] is False
     assert domain["Processing"] is False
@@ -40,7 +45,7 @@ def test_create_elasticsearch_domain_minimal():
     assert "ElasticsearchVersion" not in domain
 
 
-@mock_es
+@mock_aws
 def test_create_elasticsearch_domain():
     client = boto3.client("es", region_name="us-east-2")
     resp = client.create_elasticsearch_domain(
@@ -127,7 +132,7 @@ def test_create_elasticsearch_domain():
     assert auto_tune["State"] == "ENABLED"
 
 
-@mock_es
+@mock_aws
 def test_delete_elasticsearch_domain():
     client = boto3.client("es", region_name="ap-southeast-1")
     client.create_elasticsearch_domain(DomainName="motosearch")
@@ -136,7 +141,7 @@ def test_delete_elasticsearch_domain():
     assert client.list_domain_names()["DomainNames"] == []
 
 
-@mock_es
+@mock_aws
 def test_missing_delete_elasticsearch_domain():
     client = boto3.client("es", region_name="ap-southeast-1")
     with pytest.raises(ClientError) as exc:
@@ -150,7 +155,7 @@ def test_missing_delete_elasticsearch_domain():
     assert err["Message"] == "Domain not found: unknown"
 
 
-@mock_es
+@mock_aws
 def test_describe_invalid_domain():
     client = boto3.client("es", region_name="us-east-2")
     with pytest.raises(ClientError) as exc:
@@ -165,7 +170,7 @@ def test_describe_invalid_domain():
     assert err["Code"] == "ValidationException"
 
 
-@mock_es
+@mock_aws
 def test_describe_unknown_domain():
     client = boto3.client("es", region_name="ap-southeast-1")
     with pytest.raises(ClientError) as exc:
@@ -179,7 +184,7 @@ def test_describe_unknown_domain():
     assert err["Message"] == "Domain not found: unknown"
 
 
-@mock_es
+@mock_aws
 def test_describe_elasticsearch_domain():
     client = boto3.client("es", region_name="ap-southeast-1")
     client.create_elasticsearch_domain(DomainName="motosearch")
@@ -187,7 +192,10 @@ def test_describe_elasticsearch_domain():
 
     domain = resp["DomainStatus"]
     assert domain["DomainName"] == "motosearch"
-    assert domain["ARN"] == f"arn:aws:es:ap-southeast-1:domain/{domain['DomainId']}"
+    assert (
+        domain["ARN"]
+        == f"arn:aws:es:ap-southeast-1:{DEFAULT_ACCOUNT_ID}:domain/{domain['DomainName']}"
+    )
     assert domain["Created"] is True
     assert domain["Deleted"] is False
     assert domain["Processing"] is False
@@ -195,7 +203,17 @@ def test_describe_elasticsearch_domain():
     assert "ElasticsearchVersion" not in domain
 
 
-@mock_es
+@mock_aws
+def test_describe_elasticsearch_domain_config():
+    client = boto3.client("es", region_name="ap-southeast-1")
+    client.create_elasticsearch_domain(DomainName="motosearch")
+
+    resp = client.describe_elasticsearch_domain_config(DomainName="motosearch")
+    domain_config = resp["DomainConfig"]
+    assert domain_config["ElasticsearchClusterConfig"]["Options"]["InstanceCount"] == 1
+
+
+@mock_aws
 def test_list_domain_names_initial():
     client = boto3.client("es", region_name="eu-west-1")
     resp = client.list_domain_names()
@@ -203,7 +221,19 @@ def test_list_domain_names_initial():
     assert resp["DomainNames"] == []
 
 
-@mock_es
+@mock_aws
+def test_list_domain_names_enginetype():
+    client = boto3.client("es", region_name="us-east-1")
+    client.create_elasticsearch_domain(DomainName="elasticsearch-domain")
+
+    resp = client.list_domain_names(EngineType="Elasticsearch")
+    assert len(resp["DomainNames"]) == 1
+
+    resp = client.list_domain_names(EngineType="OpenSearch")
+    assert len(resp["DomainNames"]) == 0
+
+
+@mock_aws
 def test_list_domain_names_with_multiple_domains():
     client = boto3.client("es", region_name="eu-west-1")
     domain_names = [f"env{i}" for i in range(1, 5)]
@@ -213,4 +243,61 @@ def test_list_domain_names_with_multiple_domains():
 
     assert len(resp["DomainNames"]) == 4
     for name in domain_names:
-        assert {"DomainName": name} in resp["DomainNames"]
+        assert {"DomainName": name, "EngineType": "Elasticsearch"} in resp[
+            "DomainNames"
+        ]
+
+
+@mock_aws
+def test_describe_elasticsearch_domains():
+    client = boto3.client("es", region_name="us-east-1")
+    domain_names = [f"env{i}" for i in range(1, 5)]
+    for name in domain_names:
+        client.create_elasticsearch_domain(
+            DomainName=name,
+            ElasticsearchVersion="7.10",
+            AdvancedOptions={"option": "value"},
+            AdvancedSecurityOptions={"Enabled": False},
+        )
+    resp = client.describe_elasticsearch_domains(DomainNames=domain_names)
+
+    assert len(resp["DomainStatusList"]) == 4
+    for domain in resp["DomainStatusList"]:
+        assert domain["DomainName"] in domain_names
+        assert domain["ElasticsearchVersion"] == "7.10"
+        assert "AdvancedSecurityOptions" in domain.keys()
+        assert "AdvancedOptions" in domain.keys()
+
+    # Test for invalid domain name
+    resp = client.describe_elasticsearch_domains(DomainNames=["invalid"])
+    assert len(resp["DomainStatusList"]) == 0
+
+
+@mock_aws
+def test_list_domain_names_opensearch():
+    opensearch_client = boto3.client("opensearch", region_name="us-east-2")
+    status = opensearch_client.create_domain(DomainName="moto-opensearch")[
+        "DomainStatus"
+    ]
+    assert status["Created"]
+    assert "DomainId" in status
+    assert "DomainName" in status
+    assert status["DomainName"] == "moto-opensearch"
+
+    # ensure that elasticsearch client can describe opensearch domains as well
+    es_client = boto3.client("es", region_name="us-east-2")
+    domain_names = es_client.list_domain_names()["DomainNames"]
+    assert len(domain_names) == 1
+    assert domain_names[0]["DomainName"] == "moto-opensearch"
+    assert domain_names[0]["EngineType"] == "OpenSearch"
+
+
+@mock_aws
+def test_list_domain_names_opensearch_deleted():
+    opensearch_client = boto3.client("opensearch", region_name="us-east-2")
+    opensearch_client.create_domain(DomainName="moto-opensearch")
+    opensearch_client.delete_domain(DomainName="moto-opensearch")
+
+    # ensure that elasticsearch client can describe opensearch domains as well
+    es_client = boto3.client("es", region_name="us-east-2")
+    assert es_client.list_domain_names()["DomainNames"] == []
