@@ -502,6 +502,251 @@ def test_create_trigger():
     assert response["Name"] == trigger_name
 
 
+@mock_aws
+def test_create_trigger_with_action_with_job_name_and_crawler_name():
+    client = create_glue_client()
+    trigger_name = str(uuid4())
+
+    with pytest.raises(ClientError) as exc:
+        client.create_trigger(
+            Name=trigger_name,
+            Type="ON_DEMAND",
+            Actions=[
+                {
+                    "JobName": "test_job_name",
+                    "CrawlerName": "test_crawler_name",
+                }
+            ],
+        )
+
+    assert exc.value.response["Error"]["Code"] == "InvalidInputException"
+    assert (
+        exc.value.response["Error"]["Message"]
+        == "Both JobName and CrawlerName cannot be set together in an action"
+    )
+
+
+@mock_aws
+def test_create_conditional_trigger_with_no_predicates():
+    client = create_glue_client()
+    trigger_name = str(uuid4())
+
+    with pytest.raises(ClientError) as exc:
+        client.create_trigger(
+            Name=trigger_name,
+            Type="CONDITIONAL",
+            Actions=[
+                {
+                    "JobName": "test_job_name",
+                }
+            ],
+        )
+
+    assert exc.value.response["Error"]["Code"] == "InvalidInputException"
+    assert exc.value.response["Error"]["Message"] == "Predicate cannot be null or empty"
+
+
+@mock_aws
+def test_create_predicate_without_logical_operator():
+    client = create_glue_client()
+    trigger_name = str(uuid4())
+
+    with pytest.raises(ClientError) as exc:
+        client.create_trigger(
+            Name=trigger_name,
+            Type="CONDITIONAL",
+            Actions=[
+                {
+                    "JobName": "test_job_name",
+                }
+            ],
+            Predicate={
+                "Logical": "ANY",
+                "Conditions": [
+                    {
+                        "CrawlerName": "test_crawler_name",
+                        "CrawlState": "SUCCEEDED",
+                    }
+                ],
+            },
+        )
+
+    assert exc.value.response["Error"]["Code"] == "InvalidInputException"
+    assert (
+        exc.value.response["Error"]["Message"]
+        == "Logical operator cannot be null or empty"
+    )
+
+
+@mock_aws
+def test_create_predicate_with_invalid_logical_operator():
+    client = create_glue_client()
+    trigger_name = str(uuid4())
+
+    bad_logical_operator = "INVALID_OPERATOR"
+
+    with pytest.raises(ClientError) as exc:
+        client.create_trigger(
+            Name=trigger_name,
+            Type="CONDITIONAL",
+            Actions=[
+                {
+                    "JobName": "test_job_name",
+                }
+            ],
+            Predicate={
+                "Logical": "ANY",
+                "Conditions": [
+                    {
+                        "CrawlerName": "test_crawler_name",
+                        "CrawlState": "SUCCEEDED",
+                        "LogicalOperator": bad_logical_operator,
+                    }
+                ],
+            },
+        )
+
+    assert exc.value.response["Error"]["Code"] == "ValidationException"
+    assert (
+        exc.value.response["Error"]["Message"]
+        == f"Value '{bad_logical_operator}' at 'predicate.conditions.1.member.logicalOperator' failed to satisfy constraint: Member must satisfy enum value set: [Equals]"
+    )
+
+
+@mock_aws
+def test_create_predicate_with_no_job_state():
+    client = create_glue_client()
+    trigger_name = str(uuid4())
+
+    with pytest.raises(ClientError) as exc:
+        client.create_trigger(
+            Name=trigger_name,
+            Type="CONDITIONAL",
+            Actions=[
+                {
+                    "JobName": "test_job_name",
+                }
+            ],
+            Predicate={
+                "Logical": "ANY",
+                "Conditions": [
+                    {
+                        "JobName": "test_job_name",
+                        "LogicalOperator": "EQUALS",
+                    }
+                ],
+            },
+        )
+
+    assert exc.value.response["Error"]["Code"] == "InvalidInputException"
+    assert (
+        exc.value.response["Error"]["Message"]
+        == "State cannot be null or empty, choose from one of the following job state: [SUCCEEDED, STOPPED, FAILED, TIMEOUT]"
+    )
+
+
+@mock_aws
+def test_create_predicate_with_no_crawler_state():
+    client = create_glue_client()
+    trigger_name = str(uuid4())
+
+    with pytest.raises(ClientError) as exc:
+        client.create_trigger(
+            Name=trigger_name,
+            Type="CONDITIONAL",
+            Actions=[
+                {
+                    "JobName": "test_job_name",
+                }
+            ],
+            Predicate={
+                "Logical": "ANY",
+                "Conditions": [
+                    {
+                        "CrawlerName": "test_job_name",
+                        "LogicalOperator": "EQUALS",
+                    }
+                ],
+            },
+        )
+
+    assert exc.value.response["Error"]["Code"] == "InvalidInputException"
+    assert (
+        exc.value.response["Error"]["Message"]
+        == "State cannot be null or empty, choose from one of the following crawler state: [SUCCEEDED, FAILED, CANCELLED]"
+    )
+
+
+@mock_aws
+def test_create_predicate_with_no_crawler_name_or_job_name():
+    client = create_glue_client()
+    trigger_name = str(uuid4())
+
+    with pytest.raises(ClientError) as exc:
+        client.create_trigger(
+            Name=trigger_name,
+            Type="CONDITIONAL",
+            Actions=[
+                {
+                    "JobName": "test_job_name",
+                }
+            ],
+            Predicate={
+                "Logical": "ANY",
+                "Conditions": [
+                    {
+                        "LogicalOperator": "EQUALS",
+                    }
+                ],
+            },
+        )
+
+    assert exc.value.response["Error"]["Code"] == "InvalidInputException"
+    assert (
+        exc.value.response["Error"]["Message"]
+        == "JobName or CrawlerName in condition cannot be null or empty"
+    )
+
+
+@mock_aws
+def test_create_crawler_args_not_included_if_job_args_present():
+    client = create_glue_client()
+    trigger_name = str(uuid4())
+
+    client.create_trigger(
+        Name=trigger_name,
+        Type="CONDITIONAL",
+        Actions=[
+            {
+                "JobName": "test_job_name",
+            }
+        ],
+        Predicate={
+            "Logical": "ANY",
+            "Conditions": [
+                {
+                    "CrawlerName": "test_crawler_name",
+                    "CrawlState": "SUCCEEDED",
+                    "JobName": "test_job_name",
+                    "State": "SUCCEEDED",
+                    "LogicalOperator": "EQUALS",
+                }
+            ],
+        },
+    )
+
+    trigger_response = client.get_trigger(Name=trigger_name)
+
+    assert (
+        trigger_response["Trigger"]["Predicate"]["Conditions"][0].get("CrawlerName")
+        is None
+    )
+    assert (
+        trigger_response["Trigger"]["Predicate"]["Conditions"][0].get("CrawlState")
+        is None
+    )
+
+
 @mock_aws
 def test_get_trigger_on_demand():
     client = create_glue_client()
