@@ -1,4 +1,3 @@
-"""Unit tests for identitystore-supported APIs."""
 import random
 import string
 from uuid import UUID, uuid4
@@ -7,7 +6,7 @@ import boto3
 import pytest
 from botocore.exceptions import ClientError
 
-from moto import mock_identitystore
+from moto import mock_aws
 from moto.moto_api._internal import mock_random
 
 # See our Development Tips on writing tests for hints on how to write good tests:
@@ -19,7 +18,7 @@ def get_identity_store_id() -> str:
     return f"d-{rand}"
 
 
-@mock_identitystore
+@mock_aws
 def test_create_group():
     client = boto3.client("identitystore", region_name="us-east-2")
     identity_store_id = get_identity_store_id()
@@ -32,7 +31,7 @@ def test_create_group():
     assert UUID(create_resp["GroupId"])
 
 
-@mock_identitystore
+@mock_aws
 def test_create_group_duplicate_name():
     client = boto3.client("identitystore", region_name="us-east-2")
     identity_store_id = get_identity_store_id()
@@ -64,7 +63,7 @@ def test_create_group_duplicate_name():
     assert err.response["Reason"] == "UNIQUENESS_CONSTRAINT_VIOLATION"
 
 
-@mock_identitystore
+@mock_aws
 def test_group_multiple_identity_stores():
     identity_store_id = get_identity_store_id()
     identity_store_id2 = get_identity_store_id()
@@ -79,7 +78,7 @@ def test_group_multiple_identity_stores():
     assert not __group_exists(client, group2[0], store_id=identity_store_id)
 
 
-@mock_identitystore
+@mock_aws
 def test_create_group_membership():
     client = boto3.client("identitystore", region_name="us-east-2")
     identity_store_id = get_identity_store_id()
@@ -111,7 +110,7 @@ def test_create_group_membership():
     assert list_response["GroupMemberships"][0]["MemberId"]["UserId"] == user_id
 
 
-@mock_identitystore
+@mock_aws
 def test_create_duplicate_username():
     client = boto3.client("identitystore", region_name="us-east-2")
     identity_store_id = get_identity_store_id()
@@ -146,7 +145,7 @@ def test_create_duplicate_username():
     assert err.response["Reason"] == "UNIQUENESS_CONSTRAINT_VIOLATION"
 
 
-@mock_identitystore
+@mock_aws
 def test_create_username_no_username():
     client = boto3.client("identitystore", region_name="us-east-2")
     identity_store_id = get_identity_store_id()
@@ -166,7 +165,7 @@ def test_create_username_no_username():
     assert err.response["Message"] == "userName is a required attribute"
 
 
-@mock_identitystore
+@mock_aws
 def test_create_username_missing_required_attributes():
     client = boto3.client("identitystore", region_name="us-east-2")
     identity_store_id = get_identity_store_id()
@@ -194,7 +193,7 @@ def test_create_username_missing_required_attributes():
     )
 
 
-@mock_identitystore
+@mock_aws
 @pytest.mark.parametrize(
     "field, missing", [("GivenName", "familyname"), ("FamilyName", "givenname")]
 )
@@ -225,7 +224,7 @@ def test_create_username_missing_required_name_field(field, missing):
     assert err.response["Message"] == f"{missing}: The attribute {missing} is required"
 
 
-@mock_identitystore
+@mock_aws
 def test_create_describe_sparse_user():
     client = boto3.client("identitystore", region_name="us-east-2")
     identity_store_id = get_identity_store_id()
@@ -248,7 +247,7 @@ def test_create_describe_sparse_user():
     assert user_resp["Name"]["FamilyName"] == "family_name"
 
 
-@mock_identitystore
+@mock_aws
 def test_create_describe_full_user():
     client = boto3.client("identitystore", region_name="us-east-2")
     identity_store_id = get_identity_store_id()
@@ -343,7 +342,7 @@ def test_create_describe_full_user():
     assert user_resp["Timezone"] == "timezone"
 
 
-@mock_identitystore
+@mock_aws
 def test_describe_user_doesnt_exist():
     client = boto3.client("identitystore", region_name="us-east-2")
     identity_store_id = get_identity_store_id()
@@ -362,7 +361,136 @@ def test_describe_user_doesnt_exist():
     assert "RequestId" in err.response
 
 
-@mock_identitystore
+@mock_aws
+def test_get_user_id_by_username():
+    client = boto3.client("identitystore", region_name="us-east-2")
+    identity_store_id = get_identity_store_id()
+    users = {}
+
+    for _ in range(1, 10):
+        user = __create_and_verify_sparse_user(client, identity_store_id)
+        users[user["UserName"]] = user["UserId"]
+
+    for name, user_id in users.items():
+        response = client.get_user_id(
+            IdentityStoreId=identity_store_id,
+            AlternateIdentifier={
+                "UniqueAttribute": {
+                    "AttributePath": "userName",
+                    "AttributeValue": name,
+                }
+            },
+        )
+
+        assert response["IdentityStoreId"] == identity_store_id
+        assert response["UserId"] == user_id
+
+
+@mock_aws
+def test_get_user_id_by_email():
+    client = boto3.client("identitystore", region_name="us-east-2")
+    identity_store_id = get_identity_store_id()
+
+    email = "test@example.com"
+
+    user = client.create_user(
+        IdentityStoreId=identity_store_id,
+        UserName="test_user",
+        DisplayName="Test User",
+        Name={"GivenName": "Test", "FamilyName": "User"},
+        Emails=[{"Value": email, "Type": "work", "Primary": True}],
+    )
+
+    response = client.get_user_id(
+        IdentityStoreId=identity_store_id,
+        AlternateIdentifier={
+            "UniqueAttribute": {
+                "AttributePath": "emails.value",
+                "AttributeValue": email,
+            }
+        },
+    )
+
+    assert response["IdentityStoreId"] == identity_store_id
+    assert response["UserId"] == user["UserId"]
+
+
+@mock_aws
+def test_get_user_id_does_not_exist():
+    client = boto3.client("identitystore", region_name="us-east-2")
+    identity_store_id = get_identity_store_id()
+
+    with pytest.raises(ClientError) as exc:
+        client.get_user_id(
+            IdentityStoreId=identity_store_id,
+            AlternateIdentifier={
+                "UniqueAttribute": {
+                    "AttributePath": "userName",
+                    "AttributeValue": "does-not-exist",
+                }
+            },
+        )
+
+    err = exc.value
+    assert err.response["Error"]["Code"] == "ResourceNotFoundException"
+    assert err.response["Error"]["Message"] == "USER not found."
+    assert err.response["ResponseMetadata"]["HTTPStatusCode"] == 400
+    assert err.response["ResourceType"] == "USER"
+    assert err.response["Message"] == "USER not found."
+    assert "RequestId" in err.response
+
+
+@mock_aws
+def test_get_user_id_empty_attribute_value():
+    client = boto3.client("identitystore", region_name="us-east-2")
+    identity_store_id = get_identity_store_id()
+
+    with pytest.raises(ClientError) as exc:
+        client.get_user_id(
+            IdentityStoreId=identity_store_id,
+            AlternateIdentifier={
+                "UniqueAttribute": {
+                    "AttributePath": "userName",
+                    "AttributeValue": "",
+                }
+            },
+        )
+
+    err = exc.value
+    assert err.response["Error"]["Code"] == "ValidationException"
+    assert (
+        err.response["Error"]["Message"]
+        == "attribute value cannot be empty or null for attribute path"
+    )
+
+
+@mock_aws
+def test_get_user_id_invalid_attribute_path():
+    client = boto3.client("identitystore", region_name="us-east-2")
+    identity_store_id = get_identity_store_id()
+
+    invalid_path = "InvalidPath"
+
+    with pytest.raises(ClientError) as exc:
+        client.get_user_id(
+            IdentityStoreId=identity_store_id,
+            AlternateIdentifier={
+                "UniqueAttribute": {
+                    "AttributePath": invalid_path,
+                    "AttributeValue": "some-value",
+                }
+            },
+        )
+
+    err = exc.value
+    assert err.response["Error"]["Code"] == "ValidationException"
+    assert (
+        err.response["Error"]["Message"]
+        == f"The attribute {invalid_path} is not a unique attribute"
+    )
+
+
+@mock_aws
 def test_get_group_id():
     client = boto3.client("identitystore", region_name="us-east-2")
     identity_store_id = get_identity_store_id()
@@ -389,7 +517,7 @@ def test_get_group_id():
         assert response["GroupId"] == group_id
 
 
-@mock_identitystore
+@mock_aws
 def test_get_group_id_does_not_exist():
     client = boto3.client("identitystore", region_name="us-east-2")
     identity_store_id = get_identity_store_id()
@@ -412,14 +540,14 @@ def test_get_group_id_does_not_exist():
     assert "RequestId" in err.response
 
 
-@mock_identitystore
+@mock_aws
 def test_list_groups():
     client = boto3.client("identitystore", region_name="us-east-2")
     identity_store_id = get_identity_store_id()
 
     start = 0
-    end = 266
-    batch_size = 100
+    end = 20
+    batch_size = 3
     next_token = None
 
     expected_groups = list()
@@ -465,7 +593,7 @@ def test_list_groups():
     assert groups == expected_groups
 
 
-@mock_identitystore
+@mock_aws
 def test_list_groups_filter():
     client = boto3.client("identitystore", region_name="us-east-2")
     identity_store_id = get_identity_store_id()
@@ -504,14 +632,14 @@ def test_list_groups_filter():
     assert len(no_groups) == 0
 
 
-@mock_identitystore
+@mock_aws
 def test_list_group_memberships():
     client = boto3.client("identitystore", region_name="us-east-2")
     identity_store_id = get_identity_store_id()
 
     start = 0
-    end = 5000
-    batch_size = 321
+    end = 20
+    batch_size = 3
     next_token = None
     membership_ids = []
 
@@ -560,7 +688,7 @@ def test_list_group_memberships():
             next_token = list_response["NextToken"]
 
 
-@mock_identitystore
+@mock_aws
 def test_list_group_memberships_for_member():
     client = boto3.client("identitystore", region_name="us-east-2")
     identity_store_id = get_identity_store_id()
@@ -622,7 +750,7 @@ def __check_membership_list_values(members, expected):
         assert members[i]["MemberId"]["UserId"] == expected[i][1]
 
 
-@mock_identitystore
+@mock_aws
 def test_list_users():
     client = boto3.client("identitystore", region_name="us-east-2")
     identity_store_id = get_identity_store_id()
@@ -665,7 +793,7 @@ def test_list_users():
     assert users == expected_users
 
 
-@mock_identitystore
+@mock_aws
 def test_list_users_filter():
     client = boto3.client("identitystore", region_name="us-east-2")
     identity_store_id = get_identity_store_id()
@@ -705,7 +833,7 @@ def test_list_users_filter():
     assert len(no_users) == 0
 
 
-@mock_identitystore
+@mock_aws
 def test_delete_group():
     client = boto3.client("identitystore", region_name="us-east-2")
     identity_store_id = get_identity_store_id()
@@ -720,7 +848,7 @@ def test_delete_group():
     assert not __group_exists(client, test_group[0], identity_store_id)
 
 
-@mock_identitystore
+@mock_aws
 def test_delete_group_doesnt_exist():
     client = boto3.client("identitystore", region_name="us-east-2")
     identity_store_id = get_identity_store_id()
@@ -734,7 +862,7 @@ def test_delete_group_doesnt_exist():
     assert not __group_exists(client, bogus_id, identity_store_id)
 
 
-@mock_identitystore
+@mock_aws
 def test_delete_group_membership():
     client = boto3.client("identitystore", region_name="eu-west-1")
     identity_store_id = get_identity_store_id()
@@ -764,7 +892,7 @@ def test_delete_group_membership():
     assert len(response["GroupMemberships"]) == 0
 
 
-@mock_identitystore
+@mock_aws
 def test_delete_user():
     client = boto3.client("identitystore", region_name="us-east-2")
     identity_store_id = get_identity_store_id()
@@ -778,7 +906,7 @@ def test_delete_user():
     assert err.response["Error"]["Code"] == "ResourceNotFoundException"
 
 
-@mock_identitystore
+@mock_aws
 def test_delete_user_doesnt_exist():
     client = boto3.client("identitystore", region_name="us-east-2")
     identity_store_id = get_identity_store_id()
@@ -789,7 +917,7 @@ def test_delete_user_doesnt_exist():
     )
 
 
-@mock_identitystore
+@mock_aws
 def test_create_describe_group() -> None:
     client = boto3.client("identitystore", region_name="us-east-2")
     identity_store_id = get_identity_store_id()
@@ -806,7 +934,7 @@ def test_create_describe_group() -> None:
     assert client_response["IdentityStoreId"] == identity_store_id
 
 
-@mock_identitystore
+@mock_aws
 def test_describe_group_doesnt_exist() -> None:
     client = boto3.client("identitystore", region_name="us-east-2")
     identity_store_id = get_identity_store_id()
