@@ -1,12 +1,12 @@
 import boto3
 
-from moto import mock_inspector2
+from moto import mock_aws
 
 # See our Development Tips on writing tests for hints on how to write good tests:
 # http://docs.getmoto.org/en/latest/docs/contributing/development_tips/tests.html
 
 
-@mock_inspector2
+@mock_aws
 def test_deleted_accounts():
     client = boto3.client("inspector2", region_name="us-east-1")
 
