@@ -5,11 +5,11 @@ import boto3
 import pytest
 from botocore.exceptions import ClientError
 
-from moto import mock_logs
+from moto import mock_aws
 from moto.core.utils import unix_time, unix_time_millis, utcnow
 
 
-@mock_logs
+@mock_aws
 def test_start_query__unknown_log_group():
     client = boto3.client("logs", "us-east-1")
 
@@ -39,7 +39,7 @@ def test_start_query__unknown_log_group():
     assert err["Message"] == "The specified log group does not exist."
 
 
-@mock_logs
+@mock_aws
 def test_get_query_results():
     client = boto3.client("logs", "us-east-1")
     log_group_name = "test"
@@ -61,7 +61,7 @@ def test_get_query_results():
     )
 
     query_id = client.start_query(
-        logGroupName="test",
+        logGroupName=log_group_name,
         startTime=int(unix_time(utcnow() - timedelta(minutes=10))),
         endTime=int(unix_time(utcnow() + timedelta(minutes=10))),
         queryString="fields @message",
@@ -90,7 +90,7 @@ def test_get_query_results():
 
     # Only find events from last 2 minutes
     query_id = client.start_query(
-        logGroupName="test",
+        logGroupName=log_group_name,
         startTime=int(unix_time(utcnow() - timedelta(minutes=2, seconds=1))),
         endTime=int(unix_time(utcnow() - timedelta(seconds=1))),
         queryString="fields @message",
@@ -98,6 +98,7 @@ def test_get_query_results():
 
     resp = client.get_query_results(queryId=query_id)
     assert len(resp["results"]) == 2
+    assert isinstance(resp["results"][0][0]["value"], str)
 
     messages = [
         row["value"]
@@ -108,7 +109,7 @@ def test_get_query_results():
     assert messages == ["event nr 2", "event nr 1"]
 
 
-@mock_logs
+@mock_aws
 def test_describe_completed_query():
     client = boto3.client("logs", "us-east-1")
 
@@ -139,7 +140,7 @@ def test_describe_completed_query():
     assert len(queries) == 0
 
 
-@mock_logs
+@mock_aws
 def test_describe_queries_on_log_group_without_any():
     client = boto3.client("logs", "us-east-1")
 
