@@ -2,7 +2,7 @@ import boto3
 import pytest
 from botocore.exceptions import ClientError
 
-from moto import mock_rds
+from moto import mock_aws
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
 DB_INSTANCE_IDENTIFIER = "db-primary-1"
@@ -23,7 +23,7 @@ def _prepare_db_instance(client):
     return resp["DBInstance"]["DBInstanceIdentifier"]
 
 
-@mock_rds
+@mock_aws
 def test_create_event_subscription():
     client = boto3.client("rds", region_name="us-west-2")
     db_identifier = _prepare_db_instance(client)
@@ -41,7 +41,7 @@ def test_create_event_subscription():
             "Restoration",
         ],
         SourceIds=[db_identifier],
-    ).get("EventSubscription")
+    )["EventSubscription"]
 
     assert es["CustSubscriptionId"] == f"{db_identifier}-events"
     assert es["SnsTopicArn"] == (
@@ -55,7 +55,7 @@ def test_create_event_subscription():
     assert es["Enabled"] is False
 
 
-@mock_rds
+@mock_aws
 def test_create_event_fail_already_exists():
     client = boto3.client("rds", region_name="us-west-2")
     db_identifier = _prepare_db_instance(client)
@@ -74,22 +74,22 @@ def test_create_event_fail_already_exists():
 
     err = ex.value.response["Error"]
 
-    assert err["Code"] == "SubscriptionAlreadyExistFault"
+    assert err["Code"] == "SubscriptionAlreadyExist"
     assert err["Message"] == "Subscription db-primary-1-events already exists."
 
 
-@mock_rds
+@mock_aws
 def test_delete_event_subscription_fails_unknown_subscription():
     client = boto3.client("rds", region_name="us-west-2")
     with pytest.raises(ClientError) as ex:
         client.delete_event_subscription(SubscriptionName="my-db-events")
 
     err = ex.value.response["Error"]
-    assert err["Code"] == "SubscriptionNotFoundFault"
+    assert err["Code"] == "SubscriptionNotFound"
     assert err["Message"] == "Subscription my-db-events not found."
 
 
-@mock_rds
+@mock_aws
 def test_delete_event_subscription():
     client = boto3.client("rds", region_name="us-west-2")
     db_identifier = _prepare_db_instance(client)
@@ -99,9 +99,9 @@ def test_delete_event_subscription():
         SnsTopicArn=f"arn:aws:sns::{ACCOUNT_ID}:{db_identifier}-events-topic",
     )
 
-    es = client.delete_event_subscription(
-        SubscriptionName=f"{db_identifier}-events"
-    ).get("EventSubscription")
+    es = client.delete_event_subscription(SubscriptionName=f"{db_identifier}-events")[
+        "EventSubscription"
+    ]
 
     assert es["CustSubscriptionId"] == f"{db_identifier}-events"
     assert es["SnsTopicArn"] == (
@@ -109,7 +109,7 @@ def test_delete_event_subscription():
     )
 
 
-@mock_rds
+@mock_aws
 def test_describe_event_subscriptions():
     client = boto3.client("rds", region_name="us-west-2")
     db_identifier = _prepare_db_instance(client)
@@ -119,13 +119,13 @@ def test_describe_event_subscriptions():
         SnsTopicArn=f"arn:aws:sns::{ACCOUNT_ID}:{db_identifier}-events-topic",
     )
 
-    subscriptions = client.describe_event_subscriptions().get("EventSubscriptionsList")
+    subscriptions = client.describe_event_subscriptions()["EventSubscriptionsList"]
 
     assert len(subscriptions) == 1
     assert subscriptions[0]["CustSubscriptionId"] == f"{db_identifier}-events"
 
 
-@mock_rds
+@mock_aws
 def test_describe_event_subscriptions_fails_unknown_subscription():
     client = boto3.client("rds", region_name="us-west-2")
     with pytest.raises(ClientError) as ex:
@@ -133,5 +133,5 @@ def test_describe_event_subscriptions_fails_unknown_subscription():
 
     err = ex.value.response["Error"]
 
-    assert err["Code"] == "SubscriptionNotFoundFault"
+    assert err["Code"] == "SubscriptionNotFound"
     assert err["Message"] == "Subscription my-db-events not found."
