@@ -2,11 +2,10 @@ import unittest
 
 import boto3
 
-from moto import mock_logs, mock_resourcegroupstaggingapi
+from moto import mock_aws
 
 
-@mock_logs
-@mock_resourcegroupstaggingapi
+@mock_aws
 class TestLogsTagging(unittest.TestCase):
     def setUp(self) -> None:
         self.logs = boto3.client("logs", region_name="us-east-2")
@@ -15,7 +14,9 @@ class TestLogsTagging(unittest.TestCase):
         self.resources_untagged = []
         for i in range(3):
             self.logs.create_log_group(logGroupName=f"test{i}", tags={"key1": "val1"})
-        self.arns = [lg["arn"] for lg in self.logs.describe_log_groups()["logGroups"]]
+        self.arns = [
+            lg["logGroupArn"] for lg in self.logs.describe_log_groups()["logGroups"]
+        ]
 
     def test_get_resources_logs(self):
         resp = self.rtapi.get_resources(ResourceTypeFilters=["logs"])
