@@ -5,7 +5,7 @@ import boto3
 import pytest
 from botocore.exceptions import ClientError
 
-from moto import mock_ssoadmin
+from moto import mock_aws
 
 # See our Development Tips on writing tests for hints on how to write good tests:
 # http://docs.getmoto.org/en/latest/docs/contributing/development_tips/tests.html
@@ -15,7 +15,7 @@ DUMMY_PERMISSIONSET_ID = (
 DUMMY_INSTANCE_ARN = "arn:aws:sso:::instance/ins-aaaabbbbccccdddd"
 
 
-@mock_ssoadmin
+@mock_aws
 def test_create_account_assignment():
     client = boto3.client("sso-admin", region_name="eu-west-1")
     target_id = "222222222222"
@@ -46,7 +46,7 @@ def test_create_account_assignment():
     assert status["PrincipalId"] == principal_id
 
 
-@mock_ssoadmin
+@mock_aws
 def test_delete_account_assignment():
     client = boto3.client("sso-admin", region_name="eu-west-1")
     target_id = "222222222222"
@@ -97,7 +97,7 @@ def test_delete_account_assignment():
     assert resp["AccountAssignments"] == []
 
 
-@mock_ssoadmin
+@mock_aws
 def test_delete_account_assignment_unknown():
     client = boto3.client("sso-admin", region_name="us-east-1")
 
@@ -121,7 +121,7 @@ def test_delete_account_assignment_unknown():
     assert err["Code"] == "ResourceNotFoundException"
 
 
-@mock_ssoadmin
+@mock_aws
 def test_list_account_assignments():
     client = boto3.client("sso-admin", region_name="ap-southeast-1")
 
@@ -190,7 +190,7 @@ def test_list_account_assignments():
     ]
 
 
-@mock_ssoadmin
+@mock_aws
 def test_list_account_assignments_pagination():
     client = boto3.client("sso-admin", region_name="ap-southeast-1")
     DUMMY_AWS_ACCOUNT_ID = "111111111111"
@@ -250,7 +250,7 @@ def test_list_account_assignments_pagination():
     )
 
 
-@mock_ssoadmin
+@mock_aws
 def test_list_account_assignments_for_principal():
     client = boto3.client("sso-admin", region_name="us-west-2")
 
@@ -333,7 +333,7 @@ def test_list_account_assignments_for_principal():
     assert len(response["AccountAssignments"]) == 0
 
 
-@mock_ssoadmin
+@mock_aws
 def test_list_account_assignments_for_principal_pagination():
     client = boto3.client("sso-admin", region_name="us-east-2")
 
@@ -384,7 +384,7 @@ def test_list_account_assignments_for_principal_pagination():
     ) == set(["000000000000", "111111111111", "222222222222"])
 
 
-@mock_ssoadmin
+@mock_aws
 def test_create_permission_set():
     client = boto3.client("sso-admin", region_name="ap-southeast-1")
     resp = client.create_permission_set(
@@ -404,7 +404,7 @@ def test_create_permission_set():
     assert "RelayState" in permission_set
 
 
-@mock_ssoadmin
+@mock_aws
 def test_update_permission_set():
     client = boto3.client("sso-admin", region_name="ap-southeast-1")
     resp = client.create_permission_set(
@@ -435,7 +435,7 @@ def test_update_permission_set():
     assert permission_set["RelayState"] == "https://console.aws.amazon.com/s3"
 
 
-@mock_ssoadmin
+@mock_aws
 def test_update_permission_set_unknown():
     client = boto3.client("sso-admin", region_name="ap-southeast-1")
 
@@ -443,8 +443,7 @@ def test_update_permission_set_unknown():
         client.update_permission_set(
             InstanceArn="arn:aws:sso:::instance/ins-aaaabbbbccccdddd",
             PermissionSetArn=(
-                "arn:aws:sso:::permissionSet/ins-eeeeffffgggghhhh/"
-                "ps-hhhhkkkkppppoooo"
+                "arn:aws:sso:::permissionSet/ins-eeeeffffgggghhhh/ps-hhhhkkkkppppoooo"
             ),
             Description="New description",
             SessionDuration="PT2H",
@@ -454,7 +453,7 @@ def test_update_permission_set_unknown():
     assert err["Code"] == "ResourceNotFoundException"
 
 
-@mock_ssoadmin
+@mock_aws
 def test_describe_permission_set():
     client = boto3.client("sso-admin", region_name="ap-southeast-1")
     resp = client.create_permission_set(
@@ -478,7 +477,7 @@ def test_describe_permission_set():
     assert "SessionDuration" in permission_set
 
 
-@mock_ssoadmin
+@mock_aws
 def test_describe_permission_set_unknown():
     client = boto3.client("sso-admin", region_name="ap-southeast-1")
 
@@ -491,7 +490,7 @@ def test_describe_permission_set_unknown():
     assert err["Code"] == "ResourceNotFoundException"
 
 
-@mock_ssoadmin
+@mock_aws
 def test_delete_permission_set():
     client = boto3.client("sso-admin", region_name="ap-southeast-1")
     resp = client.create_permission_set(
@@ -514,7 +513,7 @@ def test_delete_permission_set():
     assert err["Code"] == "ResourceNotFoundException"
 
 
-@mock_ssoadmin
+@mock_aws
 def test_delete_permission_set_unknown():
     client = boto3.client("sso-admin", region_name="ap-southeast-1")
 
@@ -527,7 +526,7 @@ def test_delete_permission_set_unknown():
     assert err["Code"] == "ResourceNotFoundException"
 
 
-@mock_ssoadmin
+@mock_aws
 def test_list_permission_sets():
     client = boto3.client("sso-admin", region_name="ap-southeast-1")
 
@@ -553,7 +552,7 @@ def test_list_permission_sets():
     assert len(permission_sets) == 5
 
 
-@mock_ssoadmin
+@mock_aws
 def test_list_permission_sets_pagination():
     client = boto3.client("sso-admin", region_name="ap-southeast-1")
 
@@ -583,3 +582,75 @@ def test_list_permission_sets_pagination():
     )
     for page in page_iterator:
         assert len(page["PermissionSets"]) <= 5
+
+
+@mock_aws
+def test_describe_account_assignment_creation_status():
+    client = boto3.client("sso-admin", region_name="eu-west-1")
+
+    # Test that we can get the account assignment info for existing ones
+    request_id = client.create_account_assignment(
+        InstanceArn="arn:aws:sso:::instance/ins-aaaabbbbccccdddd",
+        PermissionSetArn="arn:aws:sso:::permissionSet/ins-eeeeffffgggghhhh/ps-hhhhkkkkppppoooo",
+        PrincipalType="USER",
+        PrincipalId="some-id",
+        TargetType="AWS_ACCOUNT",
+        TargetId="123123123123",
+    )["AccountAssignmentCreationStatus"]["RequestId"]
+
+    resp = client.describe_account_assignment_creation_status(
+        AccountAssignmentCreationRequestId=request_id,
+        InstanceArn="arn:aws:sso:::instance/ins-aaaabbbbccccdddd",
+    )
+    assert resp["AccountAssignmentCreationStatus"]["Status"] == "SUCCEEDED"
+    assert resp["AccountAssignmentCreationStatus"]["PrincipalId"] == "some-id"
+
+    # Test that non-existent ones raise an exception
+    with pytest.raises(ClientError) as exc:
+        client.describe_account_assignment_creation_status(
+            AccountAssignmentCreationRequestId="non-existent-create-account-assignment-id",
+            InstanceArn="arn:aws:sso:::instance/ins-aaaabbbbccccdddd",
+        )
+    err = exc.value.response["Error"]
+    assert err["Code"] == "ResourceNotFoundException"
+
+
+@mock_aws
+def test_describe_account_assignment_deletion_status():
+    client = boto3.client("sso-admin", region_name="eu-west-1")
+
+    # Create & delete an account assignment
+    client.create_account_assignment(
+        InstanceArn="arn:aws:sso:::instance/ins-aaaabbbbccccdddd",
+        PermissionSetArn="arn:aws:sso:::permissionSet/ins-eeeeffffgggghhhh/ps-hhhhkkkkppppoooo",
+        PrincipalType="USER",
+        PrincipalId="some-id",
+        TargetType="AWS_ACCOUNT",
+        TargetId="123123123123",
+    )
+
+    request_id = client.delete_account_assignment(
+        InstanceArn="arn:aws:sso:::instance/ins-aaaabbbbccccdddd",
+        PermissionSetArn="arn:aws:sso:::permissionSet/ins-eeeeffffgggghhhh/ps-hhhhkkkkppppoooo",
+        PrincipalType="USER",
+        PrincipalId="some-id",
+        TargetType="AWS_ACCOUNT",
+        TargetId="123123123123",
+    )["AccountAssignmentDeletionStatus"]["RequestId"]
+
+    # Test that we can get the account assignment info for existing ones
+    resp = client.describe_account_assignment_deletion_status(
+        AccountAssignmentDeletionRequestId=request_id,
+        InstanceArn="arn:aws:sso:::instance/ins-aaaabbbbccccdddd",
+    )
+    assert resp["AccountAssignmentDeletionStatus"]["Status"] == "SUCCEEDED"
+    assert resp["AccountAssignmentDeletionStatus"]["PrincipalId"] == "some-id"
+
+    # Test that non-existent ones raise an exception
+    with pytest.raises(ClientError) as exc:
+        client.describe_account_assignment_deletion_status(
+            AccountAssignmentDeletionRequestId="non-existent-create-account-assignment-id",
+            InstanceArn="arn:aws:sso:::instance/ins-aaaabbbbccccdddd",
+        )
+    err = exc.value.response["Error"]
+    assert err["Code"] == "ResourceNotFoundException"
